export declare const RegionResponseError: {
    new (args?: {
        message?: string;
        cause?: unknown;
    } | undefined): import("../../error.ts").RichError & {
        readonly _tag: "RegionResponseError";
    } & Readonly<Record<string, never>>;
    readonly defaultMessage?: string;
} & (<Shape extends {
    [x: string]: any;
} = Record<string, never>>() => {
    new (args?: (Shape extends Record<string, never> ? {
        message?: string;
        cause?: unknown;
    } : Shape & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("../../error.ts").RichError & {
        readonly _tag: "RegionResponseError";
    } & Readonly<Shape>;
    readonly defaultMessage?: string;
});
//# sourceMappingURL=util.d.ts.map