import { APIClient } from '../api.ts';
import { type OAuthOrgMember } from './types.ts';
export declare function oauthOrgMembers(client: APIClient): Promise<OAuthOrgMember[]>;
//# sourceMappingURL=members.d.ts.map