import { z } from 'zod';
/**
 * Response data for GET hostname (mirrors private HostnameGetDataSchema in hostname.ts)
 */
export declare const HostnameGetResponseDataSchema: z.ZodObject<{
    hostname: z.ZodNullable<z.ZodString>;
    url: z.ZodNullable<z.ZodString>;
}, z.core.$strip>;
export type HostnameGetResponseData = z.infer<typeof HostnameGetResponseDataSchema>;
/**
 * Response data for SET hostname (mirrors private HostnameSetDataSchema in hostname.ts)
 */
export declare const HostnameSetResponseDataSchema: z.ZodObject<{
    hostname: z.ZodString;
    url: z.ZodString;
}, z.core.$strip>;
export type HostnameSetResponseData = z.infer<typeof HostnameSetResponseDataSchema>;
/**
 * Request body for malware check endpoint
 */
export declare const MalwareCheckRequestSchema: z.ZodObject<{
    ecosystem: z.ZodString;
    packages: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        version: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type MalwareCheckRequest = z.infer<typeof MalwareCheckRequestSchema>;
//# sourceMappingURL=types.d.ts.map