import { z } from 'zod/v4';
export declare const CoderSessionVisibilitySchema: z.ZodEnum<{
    private: "private";
    organization: "organization";
    collaborate: "collaborate";
}>;
export type CoderSessionVisibility = z.infer<typeof CoderSessionVisibilitySchema>;
/**
 * Normalize a visibility input string to the canonical server value.
 * Accepts shortcuts like 'org' → 'organization', 'collab' → 'collaborate'.
 */
export declare function normalizeVisibility(input: string): CoderSessionVisibility;
export declare const CoderWorkflowModeSchema: z.ZodEnum<{
    standard: "standard";
    loop: "loop";
}>;
export type CoderWorkflowMode = z.infer<typeof CoderWorkflowModeSchema>;
export declare const CoderSessionModeSchema: z.ZodEnum<{
    sandbox: "sandbox";
    tui: "tui";
}>;
export type CoderSessionMode = z.infer<typeof CoderSessionModeSchema>;
export declare const CoderSessionBucketSchema: z.ZodEnum<{
    running: "running";
    paused: "paused";
    provisioning: "provisioning";
    history: "history";
}>;
export type CoderSessionBucket = z.infer<typeof CoderSessionBucketSchema>;
export declare const CoderWorkspaceSystemPromptModeSchema: z.ZodEnum<{
    append: "append";
    overwrite: "overwrite";
}>;
export type CoderWorkspaceSystemPromptMode = z.infer<typeof CoderWorkspaceSystemPromptModeSchema>;
export declare const CoderSkillRefSchema: z.ZodObject<{
    skillId: z.ZodString;
    repo: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    content: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderSkillRef = z.infer<typeof CoderSkillRefSchema>;
export declare const CoderSessionRepositoryRefSchema: z.ZodObject<{
    repoId: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodString>;
    provider: z.ZodOptional<z.ZodString>;
    owner: z.ZodOptional<z.ZodString>;
    name: z.ZodOptional<z.ZodString>;
    fullName: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    cloneUrl: z.ZodOptional<z.ZodString>;
    defaultBranch: z.ZodOptional<z.ZodString>;
    branch: z.ZodOptional<z.ZodString>;
    ref: z.ZodOptional<z.ZodString>;
    commit: z.ZodOptional<z.ZodString>;
    path: z.ZodOptional<z.ZodString>;
    rootPath: z.ZodOptional<z.ZodString>;
}, z.core.$catchall<z.ZodUnknown>>;
export type CoderSessionRepositoryRef = z.infer<typeof CoderSessionRepositoryRefSchema>;
export declare const CoderSavedSkillSchema: z.ZodObject<{
    id: z.ZodString;
    source: z.ZodString;
    repo: z.ZodString;
    skillId: z.ZodString;
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    installs: z.ZodOptional<z.ZodNumber>;
    content: z.ZodOptional<z.ZodString>;
    createdAt: z.ZodString;
    updatedAt: z.ZodString;
}, z.core.$loose>;
export type CoderSavedSkill = z.infer<typeof CoderSavedSkillSchema>;
export declare const CoderSkillBucketSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    createdAt: z.ZodString;
    updatedAt: z.ZodString;
    skillCount: z.ZodNumber;
    skills: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        source: z.ZodString;
        repo: z.ZodString;
        skillId: z.ZodString;
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        installs: z.ZodOptional<z.ZodNumber>;
        content: z.ZodOptional<z.ZodString>;
        createdAt: z.ZodString;
        updatedAt: z.ZodString;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderSkillBucket = z.infer<typeof CoderSkillBucketSchema>;
export declare const CoderWorkspaceDetailSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    scope: z.ZodString;
    ownerUserId: z.ZodString;
    repos: z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>;
    repoCount: z.ZodNumber;
    dependencies: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
    setupScript: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    systemPrompt: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    systemPromptMode: z.ZodDefault<z.ZodOptional<z.ZodEnum<{
        append: "append";
        overwrite: "overwrite";
    }>>>;
    snapshot: z.ZodOptional<z.ZodObject<{
        status: z.ZodString;
        snapshotId: z.ZodOptional<z.ZodString>;
        snapshotRef: z.ZodOptional<z.ZodString>;
        baseSnapshotRef: z.ZodOptional<z.ZodString>;
        baseDriverVersion: z.ZodOptional<z.ZodString>;
        configHash: z.ZodOptional<z.ZodString>;
        buildId: z.ZodOptional<z.ZodString>;
        requestedAt: z.ZodOptional<z.ZodString>;
        updatedAt: z.ZodOptional<z.ZodString>;
        createdAt: z.ZodOptional<z.ZodString>;
        error: z.ZodOptional<z.ZodString>;
    }, z.core.$loose>>;
    savedSkillIds: z.ZodArray<z.ZodString>;
    skillBucketIds: z.ZodArray<z.ZodString>;
    enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
    selectionCount: z.ZodNumber;
    createdAt: z.ZodString;
    updatedAt: z.ZodString;
}, z.core.$loose>;
export type CoderWorkspaceDetail = z.infer<typeof CoderWorkspaceDetailSchema>;
export declare const CoderCustomAgentThinkingLevelSchema: z.ZodEnum<{
    off: "off";
    low: "low";
    medium: "medium";
    high: "high";
    minimal: "minimal";
    xhigh: "xhigh";
}>;
export type CoderCustomAgentThinkingLevel = z.infer<typeof CoderCustomAgentThinkingLevelSchema>;
export declare const CODER_CUSTOM_AGENT_TOOLS: readonly ["read", "ls", "find", "grep", "bash", "write", "edit"];
export declare const CoderCustomAgentToolSchema: z.ZodEnum<{
    find: "find";
    read: "read";
    ls: "ls";
    grep: "grep";
    bash: "bash";
    write: "write";
    edit: "edit";
}>;
export type CoderCustomAgentTool = z.infer<typeof CoderCustomAgentToolSchema>;
export declare const CoderCustomAgentToolResponseSchema: z.ZodUnion<readonly [z.ZodEnum<{
    find: "find";
    read: "read";
    ls: "ls";
    grep: "grep";
    bash: "bash";
    write: "write";
    edit: "edit";
}>, z.ZodString]>;
export type CoderCustomAgentToolResponse = z.infer<typeof CoderCustomAgentToolResponseSchema>;
export declare const CODER_CUSTOM_AGENT_SERVICE_TOOLS: readonly ["session_dashboard", "memory_service_search", "memory_service_store", "memory_service_get", "memory_service_update", "memory_service_delete", "memory_service_list", "memory_service_schema", "memory_service_facets", "context7_search", "grep_app_search", "web_search", "fetch_content", "product_prd_create", "product_prd_get", "product_prd_update", "product_prd_list", "product_task_comment", "session_todo_create", "session_todo_update", "session_todo_list", "session_todo_comment", "session_todo_attach", "product_generate_deck", "sandbox_exec", "loop_get_state", "loop_update_state", "coord_create_job", "coord_add_task", "coord_claim_task", "coord_complete_task", "coord_fail_task", "coord_list_tasks", "coord_job_status", "coord_reserve_file", "coord_release_file", "coord_provide_contract", "coord_check_contract", "coord_send_message", "coord_read_messages", "coord_heartbeat", "coord_spawn_workers"];
export declare const CoderCustomAgentServiceToolSchema: z.ZodEnum<{
    session_dashboard: "session_dashboard";
    memory_service_search: "memory_service_search";
    memory_service_store: "memory_service_store";
    memory_service_get: "memory_service_get";
    memory_service_update: "memory_service_update";
    memory_service_delete: "memory_service_delete";
    memory_service_list: "memory_service_list";
    memory_service_schema: "memory_service_schema";
    memory_service_facets: "memory_service_facets";
    context7_search: "context7_search";
    grep_app_search: "grep_app_search";
    web_search: "web_search";
    fetch_content: "fetch_content";
    product_prd_create: "product_prd_create";
    product_prd_get: "product_prd_get";
    product_prd_update: "product_prd_update";
    product_prd_list: "product_prd_list";
    product_task_comment: "product_task_comment";
    session_todo_create: "session_todo_create";
    session_todo_update: "session_todo_update";
    session_todo_list: "session_todo_list";
    session_todo_comment: "session_todo_comment";
    session_todo_attach: "session_todo_attach";
    product_generate_deck: "product_generate_deck";
    sandbox_exec: "sandbox_exec";
    loop_get_state: "loop_get_state";
    loop_update_state: "loop_update_state";
    coord_create_job: "coord_create_job";
    coord_add_task: "coord_add_task";
    coord_claim_task: "coord_claim_task";
    coord_complete_task: "coord_complete_task";
    coord_fail_task: "coord_fail_task";
    coord_list_tasks: "coord_list_tasks";
    coord_job_status: "coord_job_status";
    coord_reserve_file: "coord_reserve_file";
    coord_release_file: "coord_release_file";
    coord_provide_contract: "coord_provide_contract";
    coord_check_contract: "coord_check_contract";
    coord_send_message: "coord_send_message";
    coord_read_messages: "coord_read_messages";
    coord_heartbeat: "coord_heartbeat";
    coord_spawn_workers: "coord_spawn_workers";
}>;
export type CoderCustomAgentServiceTool = z.infer<typeof CoderCustomAgentServiceToolSchema>;
export declare const CoderCustomAgentServiceToolResponseSchema: z.ZodUnion<readonly [z.ZodEnum<{
    session_dashboard: "session_dashboard";
    memory_service_search: "memory_service_search";
    memory_service_store: "memory_service_store";
    memory_service_get: "memory_service_get";
    memory_service_update: "memory_service_update";
    memory_service_delete: "memory_service_delete";
    memory_service_list: "memory_service_list";
    memory_service_schema: "memory_service_schema";
    memory_service_facets: "memory_service_facets";
    context7_search: "context7_search";
    grep_app_search: "grep_app_search";
    web_search: "web_search";
    fetch_content: "fetch_content";
    product_prd_create: "product_prd_create";
    product_prd_get: "product_prd_get";
    product_prd_update: "product_prd_update";
    product_prd_list: "product_prd_list";
    product_task_comment: "product_task_comment";
    session_todo_create: "session_todo_create";
    session_todo_update: "session_todo_update";
    session_todo_list: "session_todo_list";
    session_todo_comment: "session_todo_comment";
    session_todo_attach: "session_todo_attach";
    product_generate_deck: "product_generate_deck";
    sandbox_exec: "sandbox_exec";
    loop_get_state: "loop_get_state";
    loop_update_state: "loop_update_state";
    coord_create_job: "coord_create_job";
    coord_add_task: "coord_add_task";
    coord_claim_task: "coord_claim_task";
    coord_complete_task: "coord_complete_task";
    coord_fail_task: "coord_fail_task";
    coord_list_tasks: "coord_list_tasks";
    coord_job_status: "coord_job_status";
    coord_reserve_file: "coord_reserve_file";
    coord_release_file: "coord_release_file";
    coord_provide_contract: "coord_provide_contract";
    coord_check_contract: "coord_check_contract";
    coord_send_message: "coord_send_message";
    coord_read_messages: "coord_read_messages";
    coord_heartbeat: "coord_heartbeat";
    coord_spawn_workers: "coord_spawn_workers";
}>, z.ZodString]>;
export type CoderCustomAgentServiceToolResponse = z.infer<typeof CoderCustomAgentServiceToolResponseSchema>;
export declare const CoderCustomAgentSnapshotSchema: z.ZodObject<{
    slug: z.ZodString;
    displayName: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    instructions: z.ZodString;
    model: z.ZodOptional<z.ZodString>;
    thinkingLevel: z.ZodOptional<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>;
    headlessCompatible: z.ZodBoolean;
    tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>, z.ZodString]>>;
    serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>, z.ZodString]>>;
    savedSkills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
}, z.core.$loose>;
export type CoderCustomAgentSnapshot = z.infer<typeof CoderCustomAgentSnapshotSchema>;
export declare const CoderCustomAgentVersionSchema: z.ZodObject<{
    slug: z.ZodString;
    displayName: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    instructions: z.ZodString;
    model: z.ZodOptional<z.ZodString>;
    thinkingLevel: z.ZodOptional<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>;
    headlessCompatible: z.ZodBoolean;
    tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>, z.ZodString]>>;
    serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>, z.ZodString]>>;
    savedSkills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
    id: z.ZodString;
    agentId: z.ZodString;
    version: z.ZodNumber;
    createdByUserId: z.ZodString;
    createdAt: z.ZodString;
}, z.core.$loose>;
export type CoderCustomAgentVersion = z.infer<typeof CoderCustomAgentVersionSchema>;
export declare const CoderCustomAgentSchema: z.ZodObject<{
    slug: z.ZodString;
    displayName: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    instructions: z.ZodString;
    model: z.ZodOptional<z.ZodString>;
    thinkingLevel: z.ZodOptional<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>;
    headlessCompatible: z.ZodBoolean;
    tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>, z.ZodString]>>;
    serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>, z.ZodString]>>;
    savedSkills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
    id: z.ZodString;
    ownerUserId: z.ZodString;
    lifecycle: z.ZodEnum<{
        draft: "draft";
        published: "published";
        archived: "archived";
    }>;
    visibility: z.ZodEnum<{
        org: "org";
        private_draft: "private_draft";
    }>;
    createdAt: z.ZodString;
    updatedAt: z.ZodString;
    hasPublishedVersion: z.ZodBoolean;
    hasUnpublishedChanges: z.ZodBoolean;
    latestPublishedVersion: z.ZodOptional<z.ZodNumber>;
    latestPublishedAt: z.ZodOptional<z.ZodString>;
    published: z.ZodOptional<z.ZodObject<{
        slug: z.ZodString;
        displayName: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodString;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodBoolean;
        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>, z.ZodString]>>;
        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>, z.ZodString]>>;
        savedSkills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
        id: z.ZodString;
        agentId: z.ZodString;
        version: z.ZodNumber;
        createdByUserId: z.ZodString;
        createdAt: z.ZodString;
    }, z.core.$loose>>;
    draft: z.ZodOptional<z.ZodObject<{
        slug: z.ZodString;
        displayName: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodString;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodBoolean;
        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>, z.ZodString]>>;
        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>, z.ZodString]>>;
        savedSkills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderCustomAgent = z.infer<typeof CoderCustomAgentSchema>;
export declare const CoderCustomAgentListResponseSchema: z.ZodObject<{
    agents: z.ZodArray<z.ZodObject<{
        slug: z.ZodString;
        displayName: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodString;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodBoolean;
        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>, z.ZodString]>>;
        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>, z.ZodString]>>;
        savedSkills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
        id: z.ZodString;
        ownerUserId: z.ZodString;
        lifecycle: z.ZodEnum<{
            draft: "draft";
            published: "published";
            archived: "archived";
        }>;
        visibility: z.ZodEnum<{
            org: "org";
            private_draft: "private_draft";
        }>;
        createdAt: z.ZodString;
        updatedAt: z.ZodString;
        hasPublishedVersion: z.ZodBoolean;
        hasUnpublishedChanges: z.ZodBoolean;
        latestPublishedVersion: z.ZodOptional<z.ZodNumber>;
        latestPublishedAt: z.ZodOptional<z.ZodString>;
        published: z.ZodOptional<z.ZodObject<{
            slug: z.ZodString;
            displayName: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            instructions: z.ZodString;
            model: z.ZodOptional<z.ZodString>;
            thinkingLevel: z.ZodOptional<z.ZodEnum<{
                off: "off";
                low: "low";
                medium: "medium";
                high: "high";
                minimal: "minimal";
                xhigh: "xhigh";
            }>>;
            headlessCompatible: z.ZodBoolean;
            tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                find: "find";
                read: "read";
                ls: "ls";
                grep: "grep";
                bash: "bash";
                write: "write";
                edit: "edit";
            }>, z.ZodString]>>;
            serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                session_dashboard: "session_dashboard";
                memory_service_search: "memory_service_search";
                memory_service_store: "memory_service_store";
                memory_service_get: "memory_service_get";
                memory_service_update: "memory_service_update";
                memory_service_delete: "memory_service_delete";
                memory_service_list: "memory_service_list";
                memory_service_schema: "memory_service_schema";
                memory_service_facets: "memory_service_facets";
                context7_search: "context7_search";
                grep_app_search: "grep_app_search";
                web_search: "web_search";
                fetch_content: "fetch_content";
                product_prd_create: "product_prd_create";
                product_prd_get: "product_prd_get";
                product_prd_update: "product_prd_update";
                product_prd_list: "product_prd_list";
                product_task_comment: "product_task_comment";
                session_todo_create: "session_todo_create";
                session_todo_update: "session_todo_update";
                session_todo_list: "session_todo_list";
                session_todo_comment: "session_todo_comment";
                session_todo_attach: "session_todo_attach";
                product_generate_deck: "product_generate_deck";
                sandbox_exec: "sandbox_exec";
                loop_get_state: "loop_get_state";
                loop_update_state: "loop_update_state";
                coord_create_job: "coord_create_job";
                coord_add_task: "coord_add_task";
                coord_claim_task: "coord_claim_task";
                coord_complete_task: "coord_complete_task";
                coord_fail_task: "coord_fail_task";
                coord_list_tasks: "coord_list_tasks";
                coord_job_status: "coord_job_status";
                coord_reserve_file: "coord_reserve_file";
                coord_release_file: "coord_release_file";
                coord_provide_contract: "coord_provide_contract";
                coord_check_contract: "coord_check_contract";
                coord_send_message: "coord_send_message";
                coord_read_messages: "coord_read_messages";
                coord_heartbeat: "coord_heartbeat";
                coord_spawn_workers: "coord_spawn_workers";
            }>, z.ZodString]>>;
            savedSkills: z.ZodArray<z.ZodObject<{
                skillId: z.ZodString;
                repo: z.ZodString;
                name: z.ZodOptional<z.ZodString>;
                url: z.ZodOptional<z.ZodString>;
                content: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
            id: z.ZodString;
            agentId: z.ZodString;
            version: z.ZodNumber;
            createdByUserId: z.ZodString;
            createdAt: z.ZodString;
        }, z.core.$loose>>;
        draft: z.ZodOptional<z.ZodObject<{
            slug: z.ZodString;
            displayName: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            instructions: z.ZodString;
            model: z.ZodOptional<z.ZodString>;
            thinkingLevel: z.ZodOptional<z.ZodEnum<{
                off: "off";
                low: "low";
                medium: "medium";
                high: "high";
                minimal: "minimal";
                xhigh: "xhigh";
            }>>;
            headlessCompatible: z.ZodBoolean;
            tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                find: "find";
                read: "read";
                ls: "ls";
                grep: "grep";
                bash: "bash";
                write: "write";
                edit: "edit";
            }>, z.ZodString]>>;
            serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                session_dashboard: "session_dashboard";
                memory_service_search: "memory_service_search";
                memory_service_store: "memory_service_store";
                memory_service_get: "memory_service_get";
                memory_service_update: "memory_service_update";
                memory_service_delete: "memory_service_delete";
                memory_service_list: "memory_service_list";
                memory_service_schema: "memory_service_schema";
                memory_service_facets: "memory_service_facets";
                context7_search: "context7_search";
                grep_app_search: "grep_app_search";
                web_search: "web_search";
                fetch_content: "fetch_content";
                product_prd_create: "product_prd_create";
                product_prd_get: "product_prd_get";
                product_prd_update: "product_prd_update";
                product_prd_list: "product_prd_list";
                product_task_comment: "product_task_comment";
                session_todo_create: "session_todo_create";
                session_todo_update: "session_todo_update";
                session_todo_list: "session_todo_list";
                session_todo_comment: "session_todo_comment";
                session_todo_attach: "session_todo_attach";
                product_generate_deck: "product_generate_deck";
                sandbox_exec: "sandbox_exec";
                loop_get_state: "loop_get_state";
                loop_update_state: "loop_update_state";
                coord_create_job: "coord_create_job";
                coord_add_task: "coord_add_task";
                coord_claim_task: "coord_claim_task";
                coord_complete_task: "coord_complete_task";
                coord_fail_task: "coord_fail_task";
                coord_list_tasks: "coord_list_tasks";
                coord_job_status: "coord_job_status";
                coord_reserve_file: "coord_reserve_file";
                coord_release_file: "coord_release_file";
                coord_provide_contract: "coord_provide_contract";
                coord_check_contract: "coord_check_contract";
                coord_send_message: "coord_send_message";
                coord_read_messages: "coord_read_messages";
                coord_heartbeat: "coord_heartbeat";
                coord_spawn_workers: "coord_spawn_workers";
            }>, z.ZodString]>>;
            savedSkills: z.ZodArray<z.ZodObject<{
                skillId: z.ZodString;
                repo: z.ZodString;
                name: z.ZodOptional<z.ZodString>;
                url: z.ZodOptional<z.ZodString>;
                content: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
        }, z.core.$loose>>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderCustomAgentListResponse = z.infer<typeof CoderCustomAgentListResponseSchema>;
export declare const CoderCustomAgentVersionListResponseSchema: z.ZodObject<{
    versions: z.ZodArray<z.ZodObject<{
        slug: z.ZodString;
        displayName: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodString;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodBoolean;
        tools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>, z.ZodString]>>;
        serviceTools: z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>, z.ZodString]>>;
        savedSkills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
        id: z.ZodString;
        agentId: z.ZodString;
        version: z.ZodNumber;
        createdByUserId: z.ZodString;
        createdAt: z.ZodString;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderCustomAgentVersionListResponse = z.infer<typeof CoderCustomAgentVersionListResponseSchema>;
export declare const CoderSavedSkillListResponseSchema: z.ZodObject<{
    skills: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        source: z.ZodString;
        repo: z.ZodString;
        skillId: z.ZodString;
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        installs: z.ZodOptional<z.ZodNumber>;
        content: z.ZodOptional<z.ZodString>;
        createdAt: z.ZodString;
        updatedAt: z.ZodString;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderSavedSkillListResponse = z.infer<typeof CoderSavedSkillListResponseSchema>;
export declare const CoderSkillBucketListResponseSchema: z.ZodObject<{
    buckets: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        createdAt: z.ZodString;
        updatedAt: z.ZodString;
        skillCount: z.ZodNumber;
        skills: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            source: z.ZodString;
            repo: z.ZodString;
            skillId: z.ZodString;
            name: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            installs: z.ZodOptional<z.ZodNumber>;
            content: z.ZodOptional<z.ZodString>;
            createdAt: z.ZodString;
            updatedAt: z.ZodString;
        }, z.core.$loose>>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderSkillBucketListResponse = z.infer<typeof CoderSkillBucketListResponseSchema>;
export declare const CoderWorkspaceListResponseSchema: z.ZodObject<{
    workspaces: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        scope: z.ZodString;
        ownerUserId: z.ZodString;
        repos: z.ZodArray<z.ZodObject<{
            repoId: z.ZodOptional<z.ZodString>;
            type: z.ZodOptional<z.ZodString>;
            provider: z.ZodOptional<z.ZodString>;
            owner: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            fullName: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            cloneUrl: z.ZodOptional<z.ZodString>;
            defaultBranch: z.ZodOptional<z.ZodString>;
            branch: z.ZodOptional<z.ZodString>;
            ref: z.ZodOptional<z.ZodString>;
            commit: z.ZodOptional<z.ZodString>;
            path: z.ZodOptional<z.ZodString>;
            rootPath: z.ZodOptional<z.ZodString>;
        }, z.core.$catchall<z.ZodUnknown>>>;
        repoCount: z.ZodNumber;
        dependencies: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
        setupScript: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        systemPrompt: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        systemPromptMode: z.ZodDefault<z.ZodOptional<z.ZodEnum<{
            append: "append";
            overwrite: "overwrite";
        }>>>;
        snapshot: z.ZodOptional<z.ZodObject<{
            status: z.ZodString;
            snapshotId: z.ZodOptional<z.ZodString>;
            snapshotRef: z.ZodOptional<z.ZodString>;
            baseSnapshotRef: z.ZodOptional<z.ZodString>;
            baseDriverVersion: z.ZodOptional<z.ZodString>;
            configHash: z.ZodOptional<z.ZodString>;
            buildId: z.ZodOptional<z.ZodString>;
            requestedAt: z.ZodOptional<z.ZodString>;
            updatedAt: z.ZodOptional<z.ZodString>;
            createdAt: z.ZodOptional<z.ZodString>;
            error: z.ZodOptional<z.ZodString>;
        }, z.core.$loose>>;
        savedSkillIds: z.ZodArray<z.ZodString>;
        skillBucketIds: z.ZodArray<z.ZodString>;
        enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
        selectionCount: z.ZodNumber;
        createdAt: z.ZodString;
        updatedAt: z.ZodString;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderWorkspaceListResponse = z.infer<typeof CoderWorkspaceListResponseSchema>;
export declare const CoderCreateWorkspaceRequestSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    scope: z.ZodOptional<z.ZodEnum<{
        user: "user";
        org: "org";
    }>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    dependencies: z.ZodOptional<z.ZodArray<z.ZodString>>;
    setupScript: z.ZodOptional<z.ZodString>;
    systemPrompt: z.ZodOptional<z.ZodString>;
    systemPromptMode: z.ZodOptional<z.ZodEnum<{
        append: "append";
        overwrite: "overwrite";
    }>>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    skillBucketIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type CoderCreateWorkspaceRequest = z.infer<typeof CoderCreateWorkspaceRequestSchema>;
export declare const CoderUpdateWorkspaceRequestSchema: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodString>;
    scope: z.ZodOptional<z.ZodEnum<{
        user: "user";
        org: "org";
    }>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    dependencies: z.ZodOptional<z.ZodArray<z.ZodString>>;
    setupScript: z.ZodOptional<z.ZodString>;
    systemPrompt: z.ZodOptional<z.ZodString>;
    systemPromptMode: z.ZodOptional<z.ZodEnum<{
        append: "append";
        overwrite: "overwrite";
    }>>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    skillBucketIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type CoderUpdateWorkspaceRequest = z.infer<typeof CoderUpdateWorkspaceRequestSchema>;
export declare const CoderWorkspaceDependencyValidationResponseSchema: z.ZodObject<{
    valid: z.ZodArray<z.ZodString>;
    invalid: z.ZodArray<z.ZodObject<{
        package: z.ZodString;
        error: z.ZodString;
        requestedVersion: z.ZodOptional<z.ZodString>;
        availableVersions: z.ZodOptional<z.ZodArray<z.ZodString>>;
        searchUrl: z.ZodString;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderWorkspaceDependencyValidationResponse = z.infer<typeof CoderWorkspaceDependencyValidationResponseSchema>;
export declare const CoderCreateCustomAgentRequestSchema: z.ZodObject<{
    slug: z.ZodString;
    displayName: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    instructions: z.ZodString;
    model: z.ZodOptional<z.ZodString>;
    thinkingLevel: z.ZodOptional<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>;
    headlessCompatible: z.ZodOptional<z.ZodBoolean>;
    tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>>>;
    serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>>>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type CoderCreateCustomAgentRequest = z.infer<typeof CoderCreateCustomAgentRequestSchema>;
export declare const CoderUpdateCustomAgentRequestSchema: z.ZodObject<{
    slug: z.ZodOptional<z.ZodString>;
    displayName: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    instructions: z.ZodOptional<z.ZodString>;
    model: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    thinkingLevel: z.ZodOptional<z.ZodNullable<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>>;
    headlessCompatible: z.ZodOptional<z.ZodBoolean>;
    tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>>>;
    serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>>>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type CoderUpdateCustomAgentRequest = z.infer<typeof CoderUpdateCustomAgentRequestSchema>;
export declare const CoderSaveSkillRequestSchema: z.ZodObject<{
    repo: z.ZodString;
    skillId: z.ZodString;
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    source: z.ZodOptional<z.ZodString>;
    content: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderSaveSkillRequest = z.infer<typeof CoderSaveSkillRequestSchema>;
export declare const CoderCreateCustomSkillRequestSchema: z.ZodObject<{
    skillId: z.ZodString;
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    content: z.ZodString;
}, z.core.$strip>;
export type CoderCreateCustomSkillRequest = z.infer<typeof CoderCreateCustomSkillRequestSchema>;
export declare const CoderCreateSkillBucketRequestSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type CoderCreateSkillBucketRequest = z.infer<typeof CoderCreateSkillBucketRequestSchema>;
export declare const CoderSessionLoopConfigSchema: z.ZodObject<{
    goal: z.ZodOptional<z.ZodString>;
    maxIterations: z.ZodOptional<z.ZodNumber>;
    autoContinue: z.ZodOptional<z.ZodBoolean>;
    allowDetached: z.ZodOptional<z.ZodBoolean>;
}, z.core.$strip>;
export type CoderSessionLoopConfig = z.infer<typeof CoderSessionLoopConfigSchema>;
export declare const CoderCreateSessionRequestSchema: z.ZodObject<{
    task: z.ZodString;
    label: z.ZodOptional<z.ZodString>;
    agent: z.ZodOptional<z.ZodString>;
    defaultAgent: z.ZodOptional<z.ZodString>;
    visibility: z.ZodOptional<z.ZodEnum<{
        private: "private";
        organization: "organization";
        collaborate: "collaborate";
    }>>;
    workflowMode: z.ZodOptional<z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>>;
    loop: z.ZodOptional<z.ZodObject<{
        goal: z.ZodOptional<z.ZodString>;
        maxIterations: z.ZodOptional<z.ZodNumber>;
        autoContinue: z.ZodOptional<z.ZodBoolean>;
        allowDetached: z.ZodOptional<z.ZodBoolean>;
    }, z.core.$strip>>;
    tags: z.ZodOptional<z.ZodArray<z.ZodString>>;
    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
    savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    skillBucketIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
    skills: z.ZodOptional<z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>>;
    repo: z.ZodOptional<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    workspaceId: z.ZodOptional<z.ZodString>;
    env: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
}, z.core.$strip>;
export type CoderCreateSessionRequest = z.infer<typeof CoderCreateSessionRequestSchema>;
export declare const CoderCreateAgentBuilderSessionRequestSchema: z.ZodObject<{
    label: z.ZodOptional<z.ZodString>;
    prompt: z.ZodOptional<z.ZodString>;
    mode: z.ZodOptional<z.ZodEnum<{
        edit: "edit";
        new: "new";
        from_session: "from_session";
    }>>;
    visibility: z.ZodOptional<z.ZodEnum<{
        private: "private";
        organization: "organization";
        collaborate: "collaborate";
    }>>;
    sourceSessionId: z.ZodOptional<z.ZodString>;
    targetAgentId: z.ZodOptional<z.ZodString>;
    targetAgentSlug: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderCreateAgentBuilderSessionRequest = z.infer<typeof CoderCreateAgentBuilderSessionRequestSchema>;
export declare const CoderUpdateSessionRequestSchema: z.ZodObject<{
    label: z.ZodOptional<z.ZodString>;
    agent: z.ZodOptional<z.ZodString>;
    defaultAgent: z.ZodOptional<z.ZodString>;
    visibility: z.ZodOptional<z.ZodEnum<{
        private: "private";
        organization: "organization";
        collaborate: "collaborate";
    }>>;
    workflowMode: z.ZodOptional<z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>>;
    loop: z.ZodOptional<z.ZodObject<{
        goal: z.ZodOptional<z.ZodString>;
        maxIterations: z.ZodOptional<z.ZodNumber>;
        autoContinue: z.ZodOptional<z.ZodBoolean>;
        allowDetached: z.ZodOptional<z.ZodBoolean>;
    }, z.core.$strip>>;
    tags: z.ZodOptional<z.ZodArray<z.ZodString>>;
    enabledAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
    skills: z.ZodOptional<z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
}, z.core.$strip>;
export type CoderUpdateSessionRequest = z.infer<typeof CoderUpdateSessionRequestSchema>;
export declare const CoderSessionOwnerSchema: z.ZodObject<{
    userId: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderSessionOwner = z.infer<typeof CoderSessionOwnerSchema>;
export declare const CoderSessionOriginSchema: z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
    type: z.ZodString;
}, z.core.$catchall<z.ZodUnknown>>]>;
export type CoderSessionOrigin = z.infer<typeof CoderSessionOriginSchema>;
export declare const CoderSessionWorkspaceSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    scope: z.ZodEnum<{
        user: "user";
        org: "org";
    }>;
}, z.core.$strip>;
export type CoderSessionWorkspace = z.infer<typeof CoderSessionWorkspaceSchema>;
export declare const CoderAgentBuilderSessionModeSchema: z.ZodEnum<{
    edit: "edit";
    new: "new";
    from_session: "from_session";
}>;
export type CoderAgentBuilderSessionMode = z.infer<typeof CoderAgentBuilderSessionModeSchema>;
export declare const CoderAgentBuilderActionKindSchema: z.ZodEnum<{
    create_draft: "create_draft";
    update_draft: "update_draft";
    publish: "publish";
}>;
export type CoderAgentBuilderActionKind = z.infer<typeof CoderAgentBuilderActionKindSchema>;
export declare const CoderAgentBuilderSourceSessionSchema: z.ZodObject<{
    sessionId: z.ZodString;
    label: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderAgentBuilderSourceSession = z.infer<typeof CoderAgentBuilderSourceSessionSchema>;
export declare const CoderAgentBuilderTargetAgentSchema: z.ZodObject<{
    agentId: z.ZodOptional<z.ZodString>;
    slug: z.ZodString;
    displayName: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderAgentBuilderTargetAgent = z.infer<typeof CoderAgentBuilderTargetAgentSchema>;
export declare const CoderAgentBuilderProposalSchema: z.ZodObject<{
    slug: z.ZodOptional<z.ZodString>;
    displayName: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodString>;
    instructions: z.ZodOptional<z.ZodString>;
    model: z.ZodOptional<z.ZodString>;
    thinkingLevel: z.ZodOptional<z.ZodEnum<{
        off: "off";
        low: "low";
        medium: "medium";
        high: "high";
        minimal: "minimal";
        xhigh: "xhigh";
    }>>;
    headlessCompatible: z.ZodOptional<z.ZodBoolean>;
    tools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        find: "find";
        read: "read";
        ls: "ls";
        grep: "grep";
        bash: "bash";
        write: "write";
        edit: "edit";
    }>, z.ZodString]>>>;
    serviceTools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
        session_dashboard: "session_dashboard";
        memory_service_search: "memory_service_search";
        memory_service_store: "memory_service_store";
        memory_service_get: "memory_service_get";
        memory_service_update: "memory_service_update";
        memory_service_delete: "memory_service_delete";
        memory_service_list: "memory_service_list";
        memory_service_schema: "memory_service_schema";
        memory_service_facets: "memory_service_facets";
        context7_search: "context7_search";
        grep_app_search: "grep_app_search";
        web_search: "web_search";
        fetch_content: "fetch_content";
        product_prd_create: "product_prd_create";
        product_prd_get: "product_prd_get";
        product_prd_update: "product_prd_update";
        product_prd_list: "product_prd_list";
        product_task_comment: "product_task_comment";
        session_todo_create: "session_todo_create";
        session_todo_update: "session_todo_update";
        session_todo_list: "session_todo_list";
        session_todo_comment: "session_todo_comment";
        session_todo_attach: "session_todo_attach";
        product_generate_deck: "product_generate_deck";
        sandbox_exec: "sandbox_exec";
        loop_get_state: "loop_get_state";
        loop_update_state: "loop_update_state";
        coord_create_job: "coord_create_job";
        coord_add_task: "coord_add_task";
        coord_claim_task: "coord_claim_task";
        coord_complete_task: "coord_complete_task";
        coord_fail_task: "coord_fail_task";
        coord_list_tasks: "coord_list_tasks";
        coord_job_status: "coord_job_status";
        coord_reserve_file: "coord_reserve_file";
        coord_release_file: "coord_release_file";
        coord_provide_contract: "coord_provide_contract";
        coord_check_contract: "coord_check_contract";
        coord_send_message: "coord_send_message";
        coord_read_messages: "coord_read_messages";
        coord_heartbeat: "coord_heartbeat";
        coord_spawn_workers: "coord_spawn_workers";
    }>, z.ZodString]>>>;
    savedSkills: z.ZodDefault<z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>>;
    companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
}, z.core.$loose>;
export type CoderAgentBuilderProposal = z.infer<typeof CoderAgentBuilderProposalSchema>;
export declare const CoderAgentBuilderDurableStateSchema: z.ZodObject<{
    draftAgentId: z.ZodOptional<z.ZodString>;
    draftAgentSlug: z.ZodOptional<z.ZodString>;
    lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export type CoderAgentBuilderDurableState = z.infer<typeof CoderAgentBuilderDurableStateSchema>;
export declare const CoderAgentBuilderActionStateSchema: z.ZodObject<{
    kind: z.ZodEnum<{
        create_draft: "create_draft";
        update_draft: "update_draft";
        publish: "publish";
    }>;
    status: z.ZodEnum<{
        failed: "failed";
        completed: "completed";
    }>;
    occurredAt: z.ZodString;
    message: z.ZodOptional<z.ZodString>;
    agentId: z.ZodOptional<z.ZodString>;
    agentSlug: z.ZodOptional<z.ZodString>;
    publishedVersion: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export type CoderAgentBuilderActionState = z.infer<typeof CoderAgentBuilderActionStateSchema>;
export declare const CoderAgentBuilderSessionSummarySchema: z.ZodObject<{
    mode: z.ZodEnum<{
        edit: "edit";
        new: "new";
        from_session: "from_session";
    }>;
    sourceSession: z.ZodOptional<z.ZodObject<{
        sessionId: z.ZodString;
        label: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    targetAgent: z.ZodOptional<z.ZodObject<{
        agentId: z.ZodOptional<z.ZodString>;
        slug: z.ZodString;
        displayName: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    durable: z.ZodOptional<z.ZodObject<{
        draftAgentId: z.ZodOptional<z.ZodString>;
        draftAgentSlug: z.ZodOptional<z.ZodString>;
        lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
    }, z.core.$strip>>;
    lastAction: z.ZodOptional<z.ZodObject<{
        kind: z.ZodEnum<{
            create_draft: "create_draft";
            update_draft: "update_draft";
            publish: "publish";
        }>;
        status: z.ZodEnum<{
            failed: "failed";
            completed: "completed";
        }>;
        occurredAt: z.ZodString;
        message: z.ZodOptional<z.ZodString>;
        agentId: z.ZodOptional<z.ZodString>;
        agentSlug: z.ZodOptional<z.ZodString>;
        publishedVersion: z.ZodOptional<z.ZodNumber>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type CoderAgentBuilderSessionSummary = z.infer<typeof CoderAgentBuilderSessionSummarySchema>;
export declare const CoderAgentBuilderSessionStateSchema: z.ZodObject<{
    mode: z.ZodEnum<{
        edit: "edit";
        new: "new";
        from_session: "from_session";
    }>;
    sourceSession: z.ZodOptional<z.ZodObject<{
        sessionId: z.ZodString;
        label: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    targetAgent: z.ZodOptional<z.ZodObject<{
        agentId: z.ZodOptional<z.ZodString>;
        slug: z.ZodString;
        displayName: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    durable: z.ZodOptional<z.ZodObject<{
        draftAgentId: z.ZodOptional<z.ZodString>;
        draftAgentSlug: z.ZodOptional<z.ZodString>;
        lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
    }, z.core.$strip>>;
    lastAction: z.ZodOptional<z.ZodObject<{
        kind: z.ZodEnum<{
            create_draft: "create_draft";
            update_draft: "update_draft";
            publish: "publish";
        }>;
        status: z.ZodEnum<{
            failed: "failed";
            completed: "completed";
        }>;
        occurredAt: z.ZodString;
        message: z.ZodOptional<z.ZodString>;
        agentId: z.ZodOptional<z.ZodString>;
        agentSlug: z.ZodOptional<z.ZodString>;
        publishedVersion: z.ZodOptional<z.ZodNumber>;
    }, z.core.$strip>>;
    proposal: z.ZodOptional<z.ZodObject<{
        slug: z.ZodOptional<z.ZodString>;
        displayName: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodOptional<z.ZodString>;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodOptional<z.ZodBoolean>;
        tools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>, z.ZodString]>>>;
        serviceTools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>, z.ZodString]>>>;
        savedSkills: z.ZodDefault<z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>>;
        companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderAgentBuilderSessionState = z.infer<typeof CoderAgentBuilderSessionStateSchema>;
export declare const CoderSessionListItemSchema: z.ZodObject<{
    sessionId: z.ZodString;
    label: z.ZodString;
    status: z.ZodString;
    mode: z.ZodEnum<{
        sandbox: "sandbox";
        tui: "tui";
    }>;
    visibility: z.ZodString;
    owner: z.ZodOptional<z.ZodObject<{
        userId: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
        type: z.ZodString;
    }, z.core.$catchall<z.ZodUnknown>>]>>;
    repo: z.ZodOptional<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    workspace: z.ZodOptional<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        scope: z.ZodEnum<{
            user: "user";
            org: "org";
        }>;
    }, z.core.$strip>>;
    sessionKind: z.ZodOptional<z.ZodString>;
    parentSessionId: z.ZodOptional<z.ZodString>;
    coordinationJobId: z.ZodOptional<z.ZodString>;
    workflowMode: z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>;
    loopStatus: z.ZodOptional<z.ZodString>;
    loopIteration: z.ZodOptional<z.ZodNumber>;
    createdAt: z.ZodString;
    lastActivityAt: z.ZodString;
    taskCount: z.ZodNumber;
    subAgentCount: z.ZodNumber;
    observerCount: z.ZodNumber;
    participantCount: z.ZodNumber;
    tags: z.ZodArray<z.ZodString>;
    skills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
    builder: z.ZodOptional<z.ZodObject<{
        mode: z.ZodEnum<{
            edit: "edit";
            new: "new";
            from_session: "from_session";
        }>;
        sourceSession: z.ZodOptional<z.ZodObject<{
            sessionId: z.ZodString;
            label: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        targetAgent: z.ZodOptional<z.ZodObject<{
            agentId: z.ZodOptional<z.ZodString>;
            slug: z.ZodString;
            displayName: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        durable: z.ZodOptional<z.ZodObject<{
            draftAgentId: z.ZodOptional<z.ZodString>;
            draftAgentSlug: z.ZodOptional<z.ZodString>;
            lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
        lastAction: z.ZodOptional<z.ZodObject<{
            kind: z.ZodEnum<{
                create_draft: "create_draft";
                update_draft: "update_draft";
                publish: "publish";
            }>;
            status: z.ZodEnum<{
                failed: "failed";
                completed: "completed";
            }>;
            occurredAt: z.ZodString;
            message: z.ZodOptional<z.ZodString>;
            agentId: z.ZodOptional<z.ZodString>;
            agentSlug: z.ZodOptional<z.ZodString>;
            publishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
    }, z.core.$strip>>;
    defaultAgent: z.ZodOptional<z.ZodString>;
    bucket: z.ZodEnum<{
        running: "running";
        paused: "paused";
        provisioning: "provisioning";
        history: "history";
    }>;
    runtimeAvailable: z.ZodBoolean;
    controlAvailable: z.ZodBoolean;
    manageAvailable: z.ZodOptional<z.ZodBoolean>;
    wakeAvailable: z.ZodBoolean;
    historyOnly: z.ZodBoolean;
    liveExpected: z.ZodBoolean;
}, z.core.$strip>;
export type CoderSessionListItem = z.infer<typeof CoderSessionListItemSchema>;
export declare const CoderSessionSchema: z.ZodObject<{
    sessionId: z.ZodString;
    label: z.ZodString;
    status: z.ZodString;
    mode: z.ZodEnum<{
        sandbox: "sandbox";
        tui: "tui";
    }>;
    visibility: z.ZodString;
    owner: z.ZodOptional<z.ZodObject<{
        userId: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
        type: z.ZodString;
    }, z.core.$catchall<z.ZodUnknown>>]>>;
    repo: z.ZodOptional<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    workspace: z.ZodOptional<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        scope: z.ZodEnum<{
            user: "user";
            org: "org";
        }>;
    }, z.core.$strip>>;
    sessionKind: z.ZodOptional<z.ZodString>;
    parentSessionId: z.ZodOptional<z.ZodString>;
    coordinationJobId: z.ZodOptional<z.ZodString>;
    workflowMode: z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>;
    loopStatus: z.ZodOptional<z.ZodString>;
    loopIteration: z.ZodOptional<z.ZodNumber>;
    createdAt: z.ZodString;
    tags: z.ZodArray<z.ZodString>;
    skills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
    defaultAgent: z.ZodOptional<z.ZodString>;
    bucket: z.ZodEnum<{
        running: "running";
        paused: "paused";
        provisioning: "provisioning";
        history: "history";
    }>;
    runtimeAvailable: z.ZodBoolean;
    controlAvailable: z.ZodBoolean;
    manageAvailable: z.ZodOptional<z.ZodBoolean>;
    wakeAvailable: z.ZodBoolean;
    historyOnly: z.ZodBoolean;
    liveExpected: z.ZodBoolean;
    task: z.ZodOptional<z.ZodString>;
    env: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    updatedAt: z.ZodOptional<z.ZodString>;
    builder: z.ZodOptional<z.ZodObject<{
        mode: z.ZodEnum<{
            edit: "edit";
            new: "new";
            from_session: "from_session";
        }>;
        sourceSession: z.ZodOptional<z.ZodObject<{
            sessionId: z.ZodString;
            label: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        targetAgent: z.ZodOptional<z.ZodObject<{
            agentId: z.ZodOptional<z.ZodString>;
            slug: z.ZodString;
            displayName: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        durable: z.ZodOptional<z.ZodObject<{
            draftAgentId: z.ZodOptional<z.ZodString>;
            draftAgentSlug: z.ZodOptional<z.ZodString>;
            lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
        lastAction: z.ZodOptional<z.ZodObject<{
            kind: z.ZodEnum<{
                create_draft: "create_draft";
                update_draft: "update_draft";
                publish: "publish";
            }>;
            status: z.ZodEnum<{
                failed: "failed";
                completed: "completed";
            }>;
            occurredAt: z.ZodString;
            message: z.ZodOptional<z.ZodString>;
            agentId: z.ZodOptional<z.ZodString>;
            agentSlug: z.ZodOptional<z.ZodString>;
            publishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
        proposal: z.ZodOptional<z.ZodObject<{
            slug: z.ZodOptional<z.ZodString>;
            displayName: z.ZodOptional<z.ZodString>;
            description: z.ZodOptional<z.ZodString>;
            instructions: z.ZodOptional<z.ZodString>;
            model: z.ZodOptional<z.ZodString>;
            thinkingLevel: z.ZodOptional<z.ZodEnum<{
                off: "off";
                low: "low";
                medium: "medium";
                high: "high";
                minimal: "minimal";
                xhigh: "xhigh";
            }>>;
            headlessCompatible: z.ZodOptional<z.ZodBoolean>;
            tools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                find: "find";
                read: "read";
                ls: "ls";
                grep: "grep";
                bash: "bash";
                write: "write";
                edit: "edit";
            }>, z.ZodString]>>>;
            serviceTools: z.ZodDefault<z.ZodArray<z.ZodUnion<readonly [z.ZodEnum<{
                session_dashboard: "session_dashboard";
                memory_service_search: "memory_service_search";
                memory_service_store: "memory_service_store";
                memory_service_get: "memory_service_get";
                memory_service_update: "memory_service_update";
                memory_service_delete: "memory_service_delete";
                memory_service_list: "memory_service_list";
                memory_service_schema: "memory_service_schema";
                memory_service_facets: "memory_service_facets";
                context7_search: "context7_search";
                grep_app_search: "grep_app_search";
                web_search: "web_search";
                fetch_content: "fetch_content";
                product_prd_create: "product_prd_create";
                product_prd_get: "product_prd_get";
                product_prd_update: "product_prd_update";
                product_prd_list: "product_prd_list";
                product_task_comment: "product_task_comment";
                session_todo_create: "session_todo_create";
                session_todo_update: "session_todo_update";
                session_todo_list: "session_todo_list";
                session_todo_comment: "session_todo_comment";
                session_todo_attach: "session_todo_attach";
                product_generate_deck: "product_generate_deck";
                sandbox_exec: "sandbox_exec";
                loop_get_state: "loop_get_state";
                loop_update_state: "loop_update_state";
                coord_create_job: "coord_create_job";
                coord_add_task: "coord_add_task";
                coord_claim_task: "coord_claim_task";
                coord_complete_task: "coord_complete_task";
                coord_fail_task: "coord_fail_task";
                coord_list_tasks: "coord_list_tasks";
                coord_job_status: "coord_job_status";
                coord_reserve_file: "coord_reserve_file";
                coord_release_file: "coord_release_file";
                coord_provide_contract: "coord_provide_contract";
                coord_check_contract: "coord_check_contract";
                coord_send_message: "coord_send_message";
                coord_read_messages: "coord_read_messages";
                coord_heartbeat: "coord_heartbeat";
                coord_spawn_workers: "coord_spawn_workers";
            }>, z.ZodString]>>>;
            savedSkills: z.ZodDefault<z.ZodArray<z.ZodObject<{
                skillId: z.ZodString;
                repo: z.ZodString;
                name: z.ZodOptional<z.ZodString>;
                url: z.ZodOptional<z.ZodString>;
                content: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>>;
            companionAgents: z.ZodDefault<z.ZodArray<z.ZodString>>;
        }, z.core.$loose>>;
    }, z.core.$loose>>;
    lastActivityAt: z.ZodOptional<z.ZodString>;
    taskCount: z.ZodOptional<z.ZodNumber>;
    subAgentCount: z.ZodOptional<z.ZodNumber>;
    observerCount: z.ZodOptional<z.ZodNumber>;
    participantCount: z.ZodOptional<z.ZodNumber>;
}, z.core.$loose>;
export type CoderSession = z.infer<typeof CoderSessionSchema>;
export declare const CoderListSessionsParamsSchema: z.ZodObject<{
    search: z.ZodOptional<z.ZodString>;
    includeArchived: z.ZodOptional<z.ZodBoolean>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListSessionsParams = z.infer<typeof CoderListSessionsParamsSchema>;
export declare const CoderSessionListResponseSchema: z.ZodObject<{
    sessions: z.ZodArray<z.ZodObject<{
        sessionId: z.ZodString;
        label: z.ZodString;
        status: z.ZodString;
        mode: z.ZodEnum<{
            sandbox: "sandbox";
            tui: "tui";
        }>;
        visibility: z.ZodString;
        owner: z.ZodOptional<z.ZodObject<{
            userId: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
            type: z.ZodString;
        }, z.core.$catchall<z.ZodUnknown>>]>>;
        repo: z.ZodOptional<z.ZodObject<{
            repoId: z.ZodOptional<z.ZodString>;
            type: z.ZodOptional<z.ZodString>;
            provider: z.ZodOptional<z.ZodString>;
            owner: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            fullName: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            cloneUrl: z.ZodOptional<z.ZodString>;
            defaultBranch: z.ZodOptional<z.ZodString>;
            branch: z.ZodOptional<z.ZodString>;
            ref: z.ZodOptional<z.ZodString>;
            commit: z.ZodOptional<z.ZodString>;
            path: z.ZodOptional<z.ZodString>;
            rootPath: z.ZodOptional<z.ZodString>;
        }, z.core.$catchall<z.ZodUnknown>>>;
        repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
            repoId: z.ZodOptional<z.ZodString>;
            type: z.ZodOptional<z.ZodString>;
            provider: z.ZodOptional<z.ZodString>;
            owner: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            fullName: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            cloneUrl: z.ZodOptional<z.ZodString>;
            defaultBranch: z.ZodOptional<z.ZodString>;
            branch: z.ZodOptional<z.ZodString>;
            ref: z.ZodOptional<z.ZodString>;
            commit: z.ZodOptional<z.ZodString>;
            path: z.ZodOptional<z.ZodString>;
            rootPath: z.ZodOptional<z.ZodString>;
        }, z.core.$catchall<z.ZodUnknown>>>>;
        workspace: z.ZodOptional<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            scope: z.ZodEnum<{
                user: "user";
                org: "org";
            }>;
        }, z.core.$strip>>;
        sessionKind: z.ZodOptional<z.ZodString>;
        parentSessionId: z.ZodOptional<z.ZodString>;
        coordinationJobId: z.ZodOptional<z.ZodString>;
        workflowMode: z.ZodEnum<{
            standard: "standard";
            loop: "loop";
        }>;
        loopStatus: z.ZodOptional<z.ZodString>;
        loopIteration: z.ZodOptional<z.ZodNumber>;
        createdAt: z.ZodString;
        lastActivityAt: z.ZodString;
        taskCount: z.ZodNumber;
        subAgentCount: z.ZodNumber;
        observerCount: z.ZodNumber;
        participantCount: z.ZodNumber;
        tags: z.ZodArray<z.ZodString>;
        skills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
        builder: z.ZodOptional<z.ZodObject<{
            mode: z.ZodEnum<{
                edit: "edit";
                new: "new";
                from_session: "from_session";
            }>;
            sourceSession: z.ZodOptional<z.ZodObject<{
                sessionId: z.ZodString;
                label: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            targetAgent: z.ZodOptional<z.ZodObject<{
                agentId: z.ZodOptional<z.ZodString>;
                slug: z.ZodString;
                displayName: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            durable: z.ZodOptional<z.ZodObject<{
                draftAgentId: z.ZodOptional<z.ZodString>;
                draftAgentSlug: z.ZodOptional<z.ZodString>;
                lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
            }, z.core.$strip>>;
            lastAction: z.ZodOptional<z.ZodObject<{
                kind: z.ZodEnum<{
                    create_draft: "create_draft";
                    update_draft: "update_draft";
                    publish: "publish";
                }>;
                status: z.ZodEnum<{
                    failed: "failed";
                    completed: "completed";
                }>;
                occurredAt: z.ZodString;
                message: z.ZodOptional<z.ZodString>;
                agentId: z.ZodOptional<z.ZodString>;
                agentSlug: z.ZodOptional<z.ZodString>;
                publishedVersion: z.ZodOptional<z.ZodNumber>;
            }, z.core.$strip>>;
        }, z.core.$strip>>;
        defaultAgent: z.ZodOptional<z.ZodString>;
        bucket: z.ZodEnum<{
            running: "running";
            paused: "paused";
            provisioning: "provisioning";
            history: "history";
        }>;
        runtimeAvailable: z.ZodBoolean;
        controlAvailable: z.ZodBoolean;
        manageAvailable: z.ZodOptional<z.ZodBoolean>;
        wakeAvailable: z.ZodBoolean;
        historyOnly: z.ZodBoolean;
        liveExpected: z.ZodBoolean;
    }, z.core.$strip>>;
    total: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export type CoderSessionListResponse = z.infer<typeof CoderSessionListResponseSchema>;
export declare const CoderSessionListPayloadSchema: z.ZodUnion<readonly [z.ZodArray<z.ZodObject<{
    sessionId: z.ZodString;
    label: z.ZodString;
    status: z.ZodString;
    mode: z.ZodEnum<{
        sandbox: "sandbox";
        tui: "tui";
    }>;
    visibility: z.ZodString;
    owner: z.ZodOptional<z.ZodObject<{
        userId: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
        type: z.ZodString;
    }, z.core.$catchall<z.ZodUnknown>>]>>;
    repo: z.ZodOptional<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>;
    repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
        repoId: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodString>;
        provider: z.ZodOptional<z.ZodString>;
        owner: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodString>;
        fullName: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodOptional<z.ZodString>;
        defaultBranch: z.ZodOptional<z.ZodString>;
        branch: z.ZodOptional<z.ZodString>;
        ref: z.ZodOptional<z.ZodString>;
        commit: z.ZodOptional<z.ZodString>;
        path: z.ZodOptional<z.ZodString>;
        rootPath: z.ZodOptional<z.ZodString>;
    }, z.core.$catchall<z.ZodUnknown>>>>;
    workspace: z.ZodOptional<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        scope: z.ZodEnum<{
            user: "user";
            org: "org";
        }>;
    }, z.core.$strip>>;
    sessionKind: z.ZodOptional<z.ZodString>;
    parentSessionId: z.ZodOptional<z.ZodString>;
    coordinationJobId: z.ZodOptional<z.ZodString>;
    workflowMode: z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>;
    loopStatus: z.ZodOptional<z.ZodString>;
    loopIteration: z.ZodOptional<z.ZodNumber>;
    createdAt: z.ZodString;
    lastActivityAt: z.ZodString;
    taskCount: z.ZodNumber;
    subAgentCount: z.ZodNumber;
    observerCount: z.ZodNumber;
    participantCount: z.ZodNumber;
    tags: z.ZodArray<z.ZodString>;
    skills: z.ZodArray<z.ZodObject<{
        skillId: z.ZodString;
        repo: z.ZodString;
        name: z.ZodOptional<z.ZodString>;
        url: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
    builder: z.ZodOptional<z.ZodObject<{
        mode: z.ZodEnum<{
            edit: "edit";
            new: "new";
            from_session: "from_session";
        }>;
        sourceSession: z.ZodOptional<z.ZodObject<{
            sessionId: z.ZodString;
            label: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        targetAgent: z.ZodOptional<z.ZodObject<{
            agentId: z.ZodOptional<z.ZodString>;
            slug: z.ZodString;
            displayName: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        durable: z.ZodOptional<z.ZodObject<{
            draftAgentId: z.ZodOptional<z.ZodString>;
            draftAgentSlug: z.ZodOptional<z.ZodString>;
            lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
        lastAction: z.ZodOptional<z.ZodObject<{
            kind: z.ZodEnum<{
                create_draft: "create_draft";
                update_draft: "update_draft";
                publish: "publish";
            }>;
            status: z.ZodEnum<{
                failed: "failed";
                completed: "completed";
            }>;
            occurredAt: z.ZodString;
            message: z.ZodOptional<z.ZodString>;
            agentId: z.ZodOptional<z.ZodString>;
            agentSlug: z.ZodOptional<z.ZodString>;
            publishedVersion: z.ZodOptional<z.ZodNumber>;
        }, z.core.$strip>>;
    }, z.core.$strip>>;
    defaultAgent: z.ZodOptional<z.ZodString>;
    bucket: z.ZodEnum<{
        running: "running";
        paused: "paused";
        provisioning: "provisioning";
        history: "history";
    }>;
    runtimeAvailable: z.ZodBoolean;
    controlAvailable: z.ZodBoolean;
    manageAvailable: z.ZodOptional<z.ZodBoolean>;
    wakeAvailable: z.ZodBoolean;
    historyOnly: z.ZodBoolean;
    liveExpected: z.ZodBoolean;
}, z.core.$strip>>, z.ZodObject<{
    sessions: z.ZodArray<z.ZodObject<{
        sessionId: z.ZodString;
        label: z.ZodString;
        status: z.ZodString;
        mode: z.ZodEnum<{
            sandbox: "sandbox";
            tui: "tui";
        }>;
        visibility: z.ZodString;
        owner: z.ZodOptional<z.ZodObject<{
            userId: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        origin: z.ZodOptional<z.ZodUnion<readonly [z.ZodString, z.ZodObject<{
            type: z.ZodString;
        }, z.core.$catchall<z.ZodUnknown>>]>>;
        repo: z.ZodOptional<z.ZodObject<{
            repoId: z.ZodOptional<z.ZodString>;
            type: z.ZodOptional<z.ZodString>;
            provider: z.ZodOptional<z.ZodString>;
            owner: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            fullName: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            cloneUrl: z.ZodOptional<z.ZodString>;
            defaultBranch: z.ZodOptional<z.ZodString>;
            branch: z.ZodOptional<z.ZodString>;
            ref: z.ZodOptional<z.ZodString>;
            commit: z.ZodOptional<z.ZodString>;
            path: z.ZodOptional<z.ZodString>;
            rootPath: z.ZodOptional<z.ZodString>;
        }, z.core.$catchall<z.ZodUnknown>>>;
        repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
            repoId: z.ZodOptional<z.ZodString>;
            type: z.ZodOptional<z.ZodString>;
            provider: z.ZodOptional<z.ZodString>;
            owner: z.ZodOptional<z.ZodString>;
            name: z.ZodOptional<z.ZodString>;
            fullName: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            cloneUrl: z.ZodOptional<z.ZodString>;
            defaultBranch: z.ZodOptional<z.ZodString>;
            branch: z.ZodOptional<z.ZodString>;
            ref: z.ZodOptional<z.ZodString>;
            commit: z.ZodOptional<z.ZodString>;
            path: z.ZodOptional<z.ZodString>;
            rootPath: z.ZodOptional<z.ZodString>;
        }, z.core.$catchall<z.ZodUnknown>>>>;
        workspace: z.ZodOptional<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            scope: z.ZodEnum<{
                user: "user";
                org: "org";
            }>;
        }, z.core.$strip>>;
        sessionKind: z.ZodOptional<z.ZodString>;
        parentSessionId: z.ZodOptional<z.ZodString>;
        coordinationJobId: z.ZodOptional<z.ZodString>;
        workflowMode: z.ZodEnum<{
            standard: "standard";
            loop: "loop";
        }>;
        loopStatus: z.ZodOptional<z.ZodString>;
        loopIteration: z.ZodOptional<z.ZodNumber>;
        createdAt: z.ZodString;
        lastActivityAt: z.ZodString;
        taskCount: z.ZodNumber;
        subAgentCount: z.ZodNumber;
        observerCount: z.ZodNumber;
        participantCount: z.ZodNumber;
        tags: z.ZodArray<z.ZodString>;
        skills: z.ZodArray<z.ZodObject<{
            skillId: z.ZodString;
            repo: z.ZodString;
            name: z.ZodOptional<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
        enabledAgents: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString>>>;
        builder: z.ZodOptional<z.ZodObject<{
            mode: z.ZodEnum<{
                edit: "edit";
                new: "new";
                from_session: "from_session";
            }>;
            sourceSession: z.ZodOptional<z.ZodObject<{
                sessionId: z.ZodString;
                label: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            targetAgent: z.ZodOptional<z.ZodObject<{
                agentId: z.ZodOptional<z.ZodString>;
                slug: z.ZodString;
                displayName: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
            durable: z.ZodOptional<z.ZodObject<{
                draftAgentId: z.ZodOptional<z.ZodString>;
                draftAgentSlug: z.ZodOptional<z.ZodString>;
                lastPublishedVersion: z.ZodOptional<z.ZodNumber>;
            }, z.core.$strip>>;
            lastAction: z.ZodOptional<z.ZodObject<{
                kind: z.ZodEnum<{
                    create_draft: "create_draft";
                    update_draft: "update_draft";
                    publish: "publish";
                }>;
                status: z.ZodEnum<{
                    failed: "failed";
                    completed: "completed";
                }>;
                occurredAt: z.ZodString;
                message: z.ZodOptional<z.ZodString>;
                agentId: z.ZodOptional<z.ZodString>;
                agentSlug: z.ZodOptional<z.ZodString>;
                publishedVersion: z.ZodOptional<z.ZodNumber>;
            }, z.core.$strip>>;
        }, z.core.$strip>>;
        defaultAgent: z.ZodOptional<z.ZodString>;
        bucket: z.ZodEnum<{
            running: "running";
            paused: "paused";
            provisioning: "provisioning";
            history: "history";
        }>;
        runtimeAvailable: z.ZodBoolean;
        controlAvailable: z.ZodBoolean;
        manageAvailable: z.ZodOptional<z.ZodBoolean>;
        wakeAvailable: z.ZodBoolean;
        historyOnly: z.ZodBoolean;
        liveExpected: z.ZodBoolean;
    }, z.core.$strip>>;
    total: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>]>;
export declare const CoderParticipantSchema: z.ZodObject<{
    id: z.ZodString;
    role: z.ZodString;
    transport: z.ZodOptional<z.ZodString>;
    agentRole: z.ZodOptional<z.ZodString>;
    connectedAt: z.ZodOptional<z.ZodString>;
    disconnectedAt: z.ZodOptional<z.ZodString>;
    lastActivityAt: z.ZodOptional<z.ZodString>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
}, z.core.$loose>;
export type CoderParticipant = z.infer<typeof CoderParticipantSchema>;
export declare const CoderSessionParticipantsSchema: z.ZodObject<{
    sessionId: z.ZodString;
    participants: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        role: z.ZodString;
        transport: z.ZodOptional<z.ZodString>;
        agentRole: z.ZodOptional<z.ZodString>;
        connectedAt: z.ZodOptional<z.ZodString>;
        disconnectedAt: z.ZodOptional<z.ZodString>;
        lastActivityAt: z.ZodOptional<z.ZodString>;
        metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    }, z.core.$loose>>;
}, z.core.$strip>;
export type CoderSessionParticipants = z.infer<typeof CoderSessionParticipantsSchema>;
export declare const CoderSessionReplaySchema: z.ZodObject<{
    sessionId: z.ZodString;
    replay: z.ZodOptional<z.ZodUnknown>;
    events: z.ZodOptional<z.ZodArray<z.ZodUnknown>>;
}, z.core.$loose>;
export type CoderSessionReplay = z.infer<typeof CoderSessionReplaySchema>;
export declare const CoderSessionEventSchema: z.ZodObject<{
    id: z.ZodNumber;
    event: z.ZodString;
    category: z.ZodOptional<z.ZodString>;
    agent: z.ZodOptional<z.ZodString>;
    taskId: z.ZodOptional<z.ZodString>;
    payload: z.ZodOptional<z.ZodUnknown>;
    occurredAt: z.ZodString;
    ingestedAt: z.ZodOptional<z.ZodString>;
}, z.core.$loose>;
export type CoderSessionEvent = z.infer<typeof CoderSessionEventSchema>;
export declare const CoderSessionEventHistorySchema: z.ZodObject<{
    sessionId: z.ZodString;
    events: z.ZodArray<z.ZodObject<{
        id: z.ZodNumber;
        event: z.ZodString;
        category: z.ZodOptional<z.ZodString>;
        agent: z.ZodOptional<z.ZodString>;
        taskId: z.ZodOptional<z.ZodString>;
        payload: z.ZodOptional<z.ZodUnknown>;
        occurredAt: z.ZodString;
        ingestedAt: z.ZodOptional<z.ZodString>;
    }, z.core.$loose>>;
    total: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
}, z.core.$loose>;
export type CoderSessionEventHistory = z.infer<typeof CoderSessionEventHistorySchema>;
export declare const CoderSessionDataQuerySchema: z.ZodObject<{
    sessionId: z.ZodString;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderSessionDataQuery = z.infer<typeof CoderSessionDataQuerySchema>;
export declare const CoderLoopStatusSchema: z.ZodEnum<{
    completed: "completed";
    cancelled: "cancelled";
    running: "running";
    paused: "paused";
    idle: "idle";
    starting: "starting";
    blocked: "blocked";
    awaiting_input: "awaiting_input";
}>;
export type CoderLoopStatus = z.infer<typeof CoderLoopStatusSchema>;
export declare const CoderSessionLoopStateSchema: z.ZodObject<{
    status: z.ZodEnum<{
        completed: "completed";
        cancelled: "cancelled";
        running: "running";
        paused: "paused";
        idle: "idle";
        starting: "starting";
        blocked: "blocked";
        awaiting_input: "awaiting_input";
    }>;
    iteration: z.ZodNumber;
    maxIterations: z.ZodOptional<z.ZodNumber>;
    goal: z.ZodOptional<z.ZodString>;
    summary: z.ZodOptional<z.ZodString>;
    nextAction: z.ZodOptional<z.ZodString>;
    loopId: z.ZodOptional<z.ZodString>;
    startedAt: z.ZodOptional<z.ZodNumber>;
    updatedAt: z.ZodOptional<z.ZodNumber>;
    completedAt: z.ZodOptional<z.ZodNumber>;
    lastCheckpointAt: z.ZodOptional<z.ZodNumber>;
    autoContinue: z.ZodOptional<z.ZodBoolean>;
    allowDetached: z.ZodOptional<z.ZodBoolean>;
    activePrdKey: z.ZodOptional<z.ZodString>;
    activePrdTaskId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderSessionLoopState = z.infer<typeof CoderSessionLoopStateSchema>;
export declare const CoderLoopStateResponseSchema: z.ZodObject<{
    sessionId: z.ZodString;
    workflowMode: z.ZodEnum<{
        standard: "standard";
        loop: "loop";
    }>;
    loop: z.ZodNullable<z.ZodObject<{
        status: z.ZodEnum<{
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
            paused: "paused";
            idle: "idle";
            starting: "starting";
            blocked: "blocked";
            awaiting_input: "awaiting_input";
        }>;
        iteration: z.ZodNumber;
        maxIterations: z.ZodOptional<z.ZodNumber>;
        goal: z.ZodOptional<z.ZodString>;
        summary: z.ZodOptional<z.ZodString>;
        nextAction: z.ZodOptional<z.ZodString>;
        loopId: z.ZodOptional<z.ZodString>;
        startedAt: z.ZodOptional<z.ZodNumber>;
        updatedAt: z.ZodOptional<z.ZodNumber>;
        completedAt: z.ZodOptional<z.ZodNumber>;
        lastCheckpointAt: z.ZodOptional<z.ZodNumber>;
        autoContinue: z.ZodOptional<z.ZodBoolean>;
        allowDetached: z.ZodOptional<z.ZodBoolean>;
        activePrdKey: z.ZodOptional<z.ZodString>;
        activePrdTaskId: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type CoderLoopStateResponse = z.infer<typeof CoderLoopStateResponseSchema>;
export declare const CoderGitHubAccountSchema: z.ZodObject<{
    installationId: z.ZodString;
    integrationId: z.ZodString;
    accountId: z.ZodString;
    accountName: z.ZodString;
    accountType: z.ZodString;
    avatarUrl: z.ZodOptional<z.ZodString>;
}, z.core.$loose>;
export type CoderGitHubAccount = z.infer<typeof CoderGitHubAccountSchema>;
export declare const CoderGitHubAccountListResponseSchema: z.ZodObject<{
    connected: z.ZodBoolean;
    username: z.ZodOptional<z.ZodString>;
    avatarUrl: z.ZodOptional<z.ZodString>;
    accounts: z.ZodArray<z.ZodObject<{
        installationId: z.ZodString;
        integrationId: z.ZodString;
        accountId: z.ZodString;
        accountName: z.ZodString;
        accountType: z.ZodString;
        avatarUrl: z.ZodOptional<z.ZodString>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderGitHubAccountListResponse = z.infer<typeof CoderGitHubAccountListResponseSchema>;
export declare const CoderGitHubRepositorySchema: z.ZodObject<{
    id: z.ZodNumber;
    name: z.ZodString;
    fullName: z.ZodString;
    private: z.ZodBoolean;
    defaultBranch: z.ZodOptional<z.ZodString>;
    cloneUrl: z.ZodString;
    htmlUrl: z.ZodString;
    visibility: z.ZodOptional<z.ZodString>;
    archived: z.ZodBoolean;
    disabled: z.ZodBoolean;
    owner: z.ZodObject<{
        login: z.ZodString;
        avatarUrl: z.ZodOptional<z.ZodString>;
    }, z.core.$loose>;
}, z.core.$loose>;
export type CoderGitHubRepository = z.infer<typeof CoderGitHubRepositorySchema>;
export declare const CoderGitHubRepositoryListResponseSchema: z.ZodObject<{
    accountId: z.ZodString;
    totalCount: z.ZodNumber;
    repositories: z.ZodArray<z.ZodObject<{
        id: z.ZodNumber;
        name: z.ZodString;
        fullName: z.ZodString;
        private: z.ZodBoolean;
        defaultBranch: z.ZodOptional<z.ZodString>;
        cloneUrl: z.ZodString;
        htmlUrl: z.ZodString;
        visibility: z.ZodOptional<z.ZodString>;
        archived: z.ZodBoolean;
        disabled: z.ZodBoolean;
        owner: z.ZodObject<{
            login: z.ZodString;
            avatarUrl: z.ZodOptional<z.ZodString>;
        }, z.core.$loose>;
    }, z.core.$loose>>;
}, z.core.$loose>;
export type CoderGitHubRepositoryListResponse = z.infer<typeof CoderGitHubRepositoryListResponseSchema>;
export declare const CoderUserSchema: z.ZodObject<{
    userId: z.ZodString;
    displayName: z.ZodString;
    email: z.ZodString;
    provider: z.ZodString;
    avatarUrl: z.ZodOptional<z.ZodString>;
    lastLoginAt: z.ZodString;
    lastSeenAt: z.ZodString;
    createdAt: z.ZodString;
}, z.core.$strip>;
export type CoderUser = z.infer<typeof CoderUserSchema>;
export declare const CoderListUsersParamsSchema: z.ZodObject<{
    search: z.ZodOptional<z.ZodString>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListUsersParams = z.infer<typeof CoderListUsersParamsSchema>;
export declare const CoderListUsersResponseSchema: z.ZodObject<{
    users: z.ZodArray<z.ZodObject<{
        userId: z.ZodString;
        displayName: z.ZodString;
        email: z.ZodString;
        provider: z.ZodString;
        avatarUrl: z.ZodOptional<z.ZodString>;
        lastLoginAt: z.ZodString;
        lastSeenAt: z.ZodString;
        createdAt: z.ZodString;
    }, z.core.$strip>>;
    total: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export type CoderListUsersResponse = z.infer<typeof CoderListUsersResponseSchema>;
//# sourceMappingURL=types.d.ts.map