import { type APIClient } from '../api.ts';
import { type CoderCreateSkillBucketRequest, type CoderCreateCustomSkillRequest, type CoderSavedSkill, type CoderSavedSkillListResponse, type CoderSaveSkillRequest, type CoderSkillBucket, type CoderSkillBucketListResponse } from './types.ts';
export declare function coderListSavedSkills(client: APIClient): Promise<CoderSavedSkillListResponse>;
export declare function coderSaveSkill(client: APIClient, params: {
    body: CoderSaveSkillRequest;
}): Promise<CoderSavedSkill>;
export declare function coderCreateCustomSkill(client: APIClient, params: {
    body: CoderCreateCustomSkillRequest;
}): Promise<CoderSavedSkill>;
export declare function coderDeleteSavedSkill(client: APIClient, params: {
    skillId: string;
}): Promise<void>;
export declare function coderListSkillBuckets(client: APIClient): Promise<CoderSkillBucketListResponse>;
export declare function coderCreateSkillBucket(client: APIClient, params: {
    body: CoderCreateSkillBucketRequest;
}): Promise<CoderSkillBucket>;
export declare function coderDeleteSkillBucket(client: APIClient, params: {
    bucketId: string;
}): Promise<void>;
//# sourceMappingURL=skills.d.ts.map