import { type APIClient } from '../api.ts';
import { type Job } from './types.ts';
import { z } from 'zod';
export declare const CreateJobRequestSchema: z.ZodObject<{
    command: z.ZodArray<z.ZodString>;
    streams: z.ZodOptional<z.ZodObject<{
        stdout: z.ZodOptional<z.ZodString>;
        stderr: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export declare const CreateJobDataSchema: z.ZodObject<{
    jobId: z.ZodString;
    sandboxId: z.ZodString;
    command: z.ZodArray<z.ZodString>;
    status: z.ZodEnum<{
        pending: "pending";
        failed: "failed";
        completed: "completed";
        cancelled: "cancelled";
        running: "running";
    }>;
    exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, z.core.$strip>;
export declare const CreateJobResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        jobId: z.ZodString;
        sandboxId: z.ZodString;
        command: z.ZodArray<z.ZodString>;
        status: z.ZodEnum<{
            pending: "pending";
            failed: "failed";
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
        }>;
        exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const JobCreateParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    options: z.ZodObject<{
        command: z.ZodArray<z.ZodString>;
        streams: z.ZodOptional<z.ZodObject<{
            stdout: z.ZodOptional<z.ZodString>;
            stderr: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
    }, z.core.$strip>;
    orgId: z.ZodOptional<z.ZodString>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type JobCreateParams = z.infer<typeof JobCreateParamsSchema>;
export declare function jobCreate(client: APIClient, params: JobCreateParams): Promise<Job>;
export declare const JobGetDataSchema: z.ZodObject<{
    jobId: z.ZodString;
    sandboxId: z.ZodString;
    command: z.ZodArray<z.ZodString>;
    status: z.ZodEnum<{
        pending: "pending";
        failed: "failed";
        completed: "completed";
        cancelled: "cancelled";
        running: "running";
    }>;
    exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, z.core.$strip>;
export declare const JobGetResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        jobId: z.ZodString;
        sandboxId: z.ZodString;
        command: z.ZodArray<z.ZodString>;
        status: z.ZodEnum<{
            pending: "pending";
            failed: "failed";
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
        }>;
        exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const JobGetParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    jobId: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type JobGetParams = z.infer<typeof JobGetParamsSchema>;
export declare function jobGet(client: APIClient, params: JobGetParams): Promise<Job>;
export declare const JobListDataSchema: z.ZodObject<{
    jobs: z.ZodArray<z.ZodObject<{
        jobId: z.ZodString;
        sandboxId: z.ZodString;
        command: z.ZodArray<z.ZodString>;
        status: z.ZodEnum<{
            pending: "pending";
            failed: "failed";
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
        }>;
        exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type JobListResponse = z.infer<typeof JobListDataSchema>;
export declare const JobListResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        jobs: z.ZodArray<z.ZodObject<{
            jobId: z.ZodString;
            sandboxId: z.ZodString;
            command: z.ZodArray<z.ZodString>;
            status: z.ZodEnum<{
                pending: "pending";
                failed: "failed";
                completed: "completed";
                cancelled: "cancelled";
                running: "running";
            }>;
            exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
            startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, z.core.$strip>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const JobListParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
    limit: z.ZodOptional<z.ZodNumber>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type JobListParams = z.infer<typeof JobListParamsSchema>;
export declare function jobList(client: APIClient, params: JobListParams): Promise<JobListResponse>;
export declare const JobStopDataSchema: z.ZodObject<{
    jobId: z.ZodString;
    sandboxId: z.ZodString;
    command: z.ZodArray<z.ZodString>;
    status: z.ZodEnum<{
        pending: "pending";
        failed: "failed";
        completed: "completed";
        cancelled: "cancelled";
        running: "running";
    }>;
    exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
    startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
}, z.core.$strip>;
export declare const JobStopResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        jobId: z.ZodString;
        sandboxId: z.ZodString;
        command: z.ZodArray<z.ZodString>;
        status: z.ZodEnum<{
            pending: "pending";
            failed: "failed";
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
        }>;
        exitCode: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        startedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        completedAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        error: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stdoutStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        stderrStreamUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const JobStopParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    jobId: z.ZodString;
    force: z.ZodOptional<z.ZodBoolean>;
    orgId: z.ZodOptional<z.ZodString>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type JobStopParams = z.infer<typeof JobStopParamsSchema>;
export declare function jobStop(client: APIClient, params: JobStopParams): Promise<Job>;
//# sourceMappingURL=job.d.ts.map