import { z } from 'zod';
export declare const ServiceUrlsSchema: z.ZodObject<{
    keyvalue: z.ZodString;
    stream: z.ZodString;
    vector: z.ZodString;
    aigateway: z.ZodString;
    catalyst: z.ZodString;
    otel: z.ZodString;
    sandbox: z.ZodString;
    email: z.ZodString;
}, z.core.$strip>;
export type ServiceUrls = z.infer<typeof ServiceUrlsSchema>;
/**
 * Resolve the region from the provided value or AGENTUITY_REGION environment variable.
 * Throws an error if no region can be resolved.
 */
export declare function resolveRegion(region?: string): string;
/**
 * Get service URLs from environment variables with fallback defaults.
 * Throws an error if region cannot be resolved (neither passed as parameter nor set via AGENTUITY_REGION).
 */
export declare function getServiceUrls(region?: string): ServiceUrls;
//# sourceMappingURL=config.d.ts.map