import { StructuredError } from '../../error.ts';

export const OrgResponseError = StructuredError('OrgResponseError');
export const OrgResourceResponseError = StructuredError('OrgResourceResponseError');
