import { z } from 'zod';
export declare const WorkflowSourceTypeSchema: z.ZodEnum<{
    queue: "queue";
    email: "email";
    schedule: "schedule";
    webhook: "webhook";
}>;
export type WorkflowSourceType = z.infer<typeof WorkflowSourceTypeSchema>;
export declare const WorkflowStatusSchema: z.ZodEnum<{
    disabled: "disabled";
    enabled: "enabled";
}>;
export type WorkflowStatus = z.infer<typeof WorkflowStatusSchema>;
export declare const WorkflowSchema: z.ZodObject<{
    id: z.ZodString;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    created_by: z.ZodString;
    org_id: z.ZodString;
    name: z.ZodString;
    description: z.ZodNullable<z.ZodString>;
    source_type: z.ZodEnum<{
        queue: "queue";
        email: "email";
        schedule: "schedule";
        webhook: "webhook";
    }>;
    source_ref_id: z.ZodString;
    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    status: z.ZodEnum<{
        disabled: "disabled";
        enabled: "enabled";
    }>;
    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    execution_count: z.ZodOptional<z.ZodNumber>;
    link: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type Workflow = z.infer<typeof WorkflowSchema>;
export declare const WorkflowExecutionSchema: z.ZodObject<{
    id: z.ZodString;
    workflow_id: z.ZodString;
    status: z.ZodEnum<{
        pending: "pending";
        failed: "failed";
        completed: "completed";
        running: "running";
    }>;
    started_at: z.ZodNullable<z.ZodString>;
    completed_at: z.ZodNullable<z.ZodString>;
    error: z.ZodNullable<z.ZodString>;
    steps: z.ZodOptional<z.ZodArray<z.ZodObject<{
        node_id: z.ZodString;
        node_type: z.ZodString;
        status: z.ZodString;
        started_at: z.ZodNullable<z.ZodString>;
        completed_at: z.ZodNullable<z.ZodString>;
        error: z.ZodNullable<z.ZodString>;
    }, z.core.$strip>>>;
}, z.core.$strip>;
export type WorkflowExecution = z.infer<typeof WorkflowExecutionSchema>;
export declare const WorkflowDeliverySchema: z.ZodObject<{
    id: z.ZodString;
    workflow_id: z.ZodString;
    execution_id: z.ZodString;
    destination_type: z.ZodString;
    destination_id: z.ZodString;
    status: z.ZodEnum<{
        success: "success";
        pending: "pending";
        failed: "failed";
    }>;
    sent_at: z.ZodNullable<z.ZodString>;
    response: z.ZodNullable<z.ZodUnknown>;
    error: z.ZodNullable<z.ZodString>;
}, z.core.$strip>;
export type WorkflowDelivery = z.infer<typeof WorkflowDeliverySchema>;
export declare const WorkflowActivitySchema: z.ZodObject<{
    total_workflows: z.ZodNumber;
    enabled_workflows: z.ZodNumber;
    disabled_workflows: z.ZodNumber;
    total_executions: z.ZodNumber;
    succeeded_executions: z.ZodNumber;
    failed_executions: z.ZodNumber;
    last_activity_at: z.ZodNullable<z.ZodString>;
}, z.core.$strip>;
export type WorkflowActivity = z.infer<typeof WorkflowActivitySchema>;
export declare const CreateWorkflowRequestSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    source_type: z.ZodEnum<{
        queue: "queue";
        email: "email";
        schedule: "schedule";
        webhook: "webhook";
    }>;
    source_ref_id: z.ZodString;
    source_config: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
}, z.core.$strip>;
export type CreateWorkflowRequest = z.infer<typeof CreateWorkflowRequestSchema>;
export declare const UpdateWorkflowRequestSchema: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    status: z.ZodOptional<z.ZodEnum<{
        disabled: "disabled";
        enabled: "enabled";
    }>>;
}, z.core.$strip>;
export type UpdateWorkflowRequest = z.infer<typeof UpdateWorkflowRequestSchema>;
export declare const UpdateWorkflowGraphRequestSchema: z.ZodObject<{
    nodes: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        type: z.ZodOptional<z.ZodString>;
        position: z.ZodOptional<z.ZodObject<{
            x: z.ZodNumber;
            y: z.ZodNumber;
        }, z.core.$strip>>;
        data: z.ZodOptional<z.ZodUnknown>;
    }, z.core.$strip>>;
    edges: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        source: z.ZodString;
        target: z.ZodString;
        sourceHandle: z.ZodOptional<z.ZodString>;
        targetHandle: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type UpdateWorkflowGraphRequest = z.infer<typeof UpdateWorkflowGraphRequestSchema>;
export declare const TestWorkflowRequestSchema: z.ZodObject<{
    payload: z.ZodUnknown;
}, z.core.$strip>;
export type TestWorkflowRequest = z.infer<typeof TestWorkflowRequestSchema>;
export declare const TestWorkflowResultSchema: z.ZodObject<{
    execution_id: z.ZodString;
    status: z.ZodString;
    steps: z.ZodOptional<z.ZodArray<z.ZodObject<{
        node_id: z.ZodString;
        node_type: z.ZodString;
        status: z.ZodString;
        output: z.ZodOptional<z.ZodUnknown>;
        error: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>>;
    error: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type TestWorkflowResult = z.infer<typeof TestWorkflowResultSchema>;
export declare const ListWorkflowsRequestSchema: z.ZodObject<{
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    status: z.ZodOptional<z.ZodEnum<{
        disabled: "disabled";
        enabled: "enabled";
    }>>;
    source_type: z.ZodOptional<z.ZodEnum<{
        queue: "queue";
        email: "email";
        schedule: "schedule";
        webhook: "webhook";
    }>>;
    filter: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type ListWorkflowsRequest = z.infer<typeof ListWorkflowsRequestSchema>;
export declare const WorkflowListResultSchema: z.ZodObject<{
    workflows: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        org_id: z.ZodString;
        name: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
        source_type: z.ZodEnum<{
            queue: "queue";
            email: "email";
            schedule: "schedule";
            webhook: "webhook";
        }>;
        source_ref_id: z.ZodString;
        source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        status: z.ZodEnum<{
            disabled: "disabled";
            enabled: "enabled";
        }>;
        graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        execution_count: z.ZodOptional<z.ZodNumber>;
        link: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
    total: z.ZodNumber;
}, z.core.$strip>;
export type WorkflowListResult = z.infer<typeof WorkflowListResultSchema>;
export declare const WorkflowGetResultSchema: z.ZodObject<{
    workflow: z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        org_id: z.ZodString;
        name: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
        source_type: z.ZodEnum<{
            queue: "queue";
            email: "email";
            schedule: "schedule";
            webhook: "webhook";
        }>;
        source_ref_id: z.ZodString;
        source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        status: z.ZodEnum<{
            disabled: "disabled";
            enabled: "enabled";
        }>;
        graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        execution_count: z.ZodOptional<z.ZodNumber>;
        link: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>;
}, z.core.$strip>;
export type WorkflowGetResult = z.infer<typeof WorkflowGetResultSchema>;
export declare const WorkflowCreateResultSchema: z.ZodObject<{
    workflow: z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        org_id: z.ZodString;
        name: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
        source_type: z.ZodEnum<{
            queue: "queue";
            email: "email";
            schedule: "schedule";
            webhook: "webhook";
        }>;
        source_ref_id: z.ZodString;
        source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        status: z.ZodEnum<{
            disabled: "disabled";
            enabled: "enabled";
        }>;
        graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        execution_count: z.ZodOptional<z.ZodNumber>;
        link: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>;
}, z.core.$strip>;
export type WorkflowCreateResult = z.infer<typeof WorkflowCreateResultSchema>;
export declare const WorkflowUpdateResultSchema: z.ZodObject<{
    workflow: z.ZodObject<{
        id: z.ZodString;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        created_by: z.ZodString;
        org_id: z.ZodString;
        name: z.ZodString;
        description: z.ZodNullable<z.ZodString>;
        source_type: z.ZodEnum<{
            queue: "queue";
            email: "email";
            schedule: "schedule";
            webhook: "webhook";
        }>;
        source_ref_id: z.ZodString;
        source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        status: z.ZodEnum<{
            disabled: "disabled";
            enabled: "enabled";
        }>;
        graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        execution_count: z.ZodOptional<z.ZodNumber>;
        link: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>;
}, z.core.$strip>;
export type WorkflowUpdateResult = z.infer<typeof WorkflowUpdateResultSchema>;
//# sourceMappingURL=types.d.ts.map