/**
 * Core authentication types for Agentuity.
 *
 * These types are defined in @agentuity/core to avoid circular dependencies
 * and allow packages like @agentuity/runtime to use auth types without
 * pulling in heavy dependencies like drizzle-orm.
 *
 * @module services/auth/types
 */
export {};
//# sourceMappingURL=types.js.map