import { z } from 'zod';
/** Request body for POST /stream (create stream) */
export declare const CreateStreamApiRequestSchema: z.ZodObject<{
    name: z.ZodString;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    headers: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    ttl: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
}, z.core.$strip>;
export type CreateStreamApiRequest = z.infer<typeof CreateStreamApiRequestSchema>;
/** Response for POST /stream (create stream) */
export declare const CreateStreamApiResponseSchema: z.ZodObject<{
    id: z.ZodString;
}, z.core.$strip>;
export type CreateStreamApiResponse = z.infer<typeof CreateStreamApiResponseSchema>;
/** Request body for POST /stream/list (list streams) */
export declare const ListStreamsApiRequestSchema: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    limit: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    sort: z.ZodOptional<z.ZodString>;
    direction: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type ListStreamsApiRequest = z.infer<typeof ListStreamsApiRequestSchema>;
/** Single stream info object (snake_case, matches API response) */
export declare const StreamInfoApiSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    metadata: z.ZodRecord<z.ZodString, z.ZodString>;
    url: z.ZodString;
    size_bytes: z.ZodNumber;
    expires_at: z.ZodNullable<z.ZodString>;
}, z.core.$strip>;
export type StreamInfoApi = z.infer<typeof StreamInfoApiSchema>;
/** Response for POST /stream/list. */
export declare const ListStreamsApiResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    streams: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        metadata: z.ZodRecord<z.ZodString, z.ZodString>;
        url: z.ZodString;
        size_bytes: z.ZodNumber;
        expires_at: z.ZodNullable<z.ZodString>;
    }, z.core.$strip>>;
    total: z.ZodNumber;
}, z.core.$strip>;
export type ListStreamsApiResponse = z.infer<typeof ListStreamsApiResponseSchema>;
//# sourceMappingURL=types.d.ts.map