import { z } from 'zod';
/** Request body for POST /resource/{orgId}/{region}/{database}/query */
export declare const DbExecuteQueryRequestSchema: z.ZodObject<{
    query: z.ZodString;
}, z.core.$strip>;
export type DbExecuteQueryRequest = z.infer<typeof DbExecuteQueryRequestSchema>;
//# sourceMappingURL=types.d.ts.map