import { z } from 'zod';
import { type APIClient } from '../api.ts';
import { type WebhookAnalyticsOptions, type WebhookOrgAnalytics, type WebhookTimeSeriesData } from './types.ts';
export declare const WebhookOrgAnalyticsResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        analytics: z.ZodObject<{
            period: z.ZodObject<{
                start: z.ZodString;
                end: z.ZodString;
                granularity: z.ZodOptional<z.ZodEnum<{
                    minute: "minute";
                    hour: "hour";
                    day: "day";
                }>>;
            }, z.core.$strip>;
            summary: z.ZodObject<{
                total_received: z.ZodNumber;
                total_delivered: z.ZodNumber;
                total_failed: z.ZodNumber;
            }, z.core.$strip>;
        }, z.core.$strip>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const WebhookTimeSeriesResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        timeseries: z.ZodObject<{
            period: z.ZodObject<{
                start: z.ZodString;
                end: z.ZodString;
                granularity: z.ZodOptional<z.ZodEnum<{
                    minute: "minute";
                    hour: "hour";
                    day: "day";
                }>>;
            }, z.core.$strip>;
            series: z.ZodArray<z.ZodObject<{
                timestamp: z.ZodString;
                received: z.ZodNumber;
                delivered: z.ZodNumber;
                failed: z.ZodNumber;
            }, z.core.$strip>>;
        }, z.core.$strip>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
/**
 * Get org-level webhook analytics summary.
 *
 * Returns total received, delivered, and failed counts for all webhooks in the org
 * within the specified time period.
 *
 * @param client - The API client
 * @param options - Analytics options (start, end, granularity)
 * @returns Org-level webhook analytics
 */
export declare function getWebhookOrgAnalytics(client: APIClient, options?: WebhookAnalyticsOptions): Promise<WebhookOrgAnalytics>;
/**
 * Get org-level webhook time series data.
 *
 * Returns time-bucketed received, delivered, and failed counts for all webhooks
 * in the org within the specified time period.
 *
 * @param client - The API client
 * @param options - Analytics options (start, end, granularity)
 * @returns Webhook time series data
 */
export declare function getWebhookOrgTimeSeries(client: APIClient, options?: WebhookAnalyticsOptions): Promise<WebhookTimeSeriesData>;
//# sourceMappingURL=analytics.d.ts.map