import type { Execution } from './types.ts';
import { z } from 'zod';
import type { APIClient } from '../api.ts';
export declare const ExecuteRequestSchema: z.ZodObject<{
    command: z.ZodArray<z.ZodString>;
    files: z.ZodOptional<z.ZodArray<z.ZodObject<{
        path: z.ZodString;
        content: z.ZodString;
    }, z.core.$strip>>>;
    timeout: z.ZodOptional<z.ZodString>;
    stream: z.ZodOptional<z.ZodObject<{
        stdout: z.ZodOptional<z.ZodString>;
        stderr: z.ZodOptional<z.ZodString>;
        timestamps: z.ZodOptional<z.ZodBoolean>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export declare const ExecuteDataSchema: z.ZodObject<{
    executionId: z.ZodString;
    status: z.ZodEnum<{
        failed: "failed";
        completed: "completed";
        cancelled: "cancelled";
        running: "running";
        timeout: "timeout";
        queued: "queued";
    }>;
    exitCode: z.ZodOptional<z.ZodNumber>;
    durationMs: z.ZodOptional<z.ZodNumber>;
    stdoutStreamUrl: z.ZodOptional<z.ZodString>;
    stderrStreamUrl: z.ZodOptional<z.ZodString>;
    outputTruncated: z.ZodOptional<z.ZodBoolean>;
}, z.core.$strip>;
export declare const ExecuteResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        executionId: z.ZodString;
        status: z.ZodEnum<{
            failed: "failed";
            completed: "completed";
            cancelled: "cancelled";
            running: "running";
            timeout: "timeout";
            queued: "queued";
        }>;
        exitCode: z.ZodOptional<z.ZodNumber>;
        durationMs: z.ZodOptional<z.ZodNumber>;
        stdoutStreamUrl: z.ZodOptional<z.ZodString>;
        stderrStreamUrl: z.ZodOptional<z.ZodString>;
        outputTruncated: z.ZodOptional<z.ZodBoolean>;
    }, z.core.$strip>;
    autoResumed: z.ZodOptional<z.ZodBoolean>;
}, z.core.$strip>], "success">;
export declare const SandboxExecuteParamsSchema: z.ZodObject<{
    sandboxId: z.ZodString;
    options: z.ZodCustom<{
        command: string[];
        files?: {
            path: string;
            content: Buffer<ArrayBufferLike>;
        }[] | undefined;
        timeout?: string | undefined;
        stream?: {
            stdout?: string | undefined;
            stderr?: string | undefined;
            timestamps?: boolean | undefined;
        } | undefined;
        signal?: AbortSignal | undefined;
    }, {
        command: string[];
        files?: {
            path: string;
            content: Buffer<ArrayBufferLike>;
        }[] | undefined;
        timeout?: string | undefined;
        stream?: {
            stdout?: string | undefined;
            stderr?: string | undefined;
            timestamps?: boolean | undefined;
        } | undefined;
        signal?: AbortSignal | undefined;
    }>;
    orgId: z.ZodOptional<z.ZodString>;
    signal: z.ZodOptional<z.ZodCustom<AbortSignal, AbortSignal>>;
}, z.core.$strip>;
export type SandboxExecuteParams = z.infer<typeof SandboxExecuteParamsSchema>;
/**
 * Executes a command in an existing sandbox.
 *
 * @param client - The API client to use for the request
 * @param params - Parameters including sandbox ID and execution options
 * @returns The execution result including status and stream URLs
 * @throws {SandboxResponseError} If the execution request fails
 */
export declare function sandboxExecute(client: APIClient, params: SandboxExecuteParams): Promise<Execution>;
//# sourceMappingURL=execute.d.ts.map