import { StructuredError } from "../../error.js";
export const ProjectResponseError = StructuredError('ProjectResponseError');
export const ProjectNotFoundError = StructuredError('ProjectNotFoundError')();
export const AgentNotFoundError = StructuredError('AgentNotFoundError')();
export const MalwareCheckError = StructuredError('MalwareCheckError')();
//# sourceMappingURL=util.js.map