import type { Logger } from '../logger.ts';
/**
 * Create a minimal logger that works in any environment (browser + server).
 * Used as default when no logger is provided.
 */
export declare function createMinimalLogger(): Logger;
//# sourceMappingURL=logger.d.ts.map