import { z } from 'zod/v4';
import { type APIClient } from '../api.ts';
import { type CoderCustomAgent, type CoderCustomAgentListResponse, type CoderCustomAgentVersionListResponse } from './types.ts';
export declare const CoderCustomAgentIdParamsSchema: z.ZodObject<{
    agentIdOrSlug: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderCustomAgentIdParams = z.infer<typeof CoderCustomAgentIdParamsSchema>;
export declare const CoderListCustomAgentsParamsSchema: z.ZodObject<{
    includeArchived: z.ZodOptional<z.ZodBoolean>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderListCustomAgentsParams = z.infer<typeof CoderListCustomAgentsParamsSchema>;
export declare const CoderCreateCustomAgentParamsSchema: z.ZodObject<{
    body: z.ZodObject<{
        slug: z.ZodString;
        displayName: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        instructions: z.ZodString;
        model: z.ZodOptional<z.ZodString>;
        thinkingLevel: z.ZodOptional<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>;
        headlessCompatible: z.ZodOptional<z.ZodBoolean>;
        tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>>>;
        serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>>>;
        savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
        companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
    }, z.core.$strip>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderCreateCustomAgentParams = z.infer<typeof CoderCreateCustomAgentParamsSchema>;
export declare const CoderUpdateCustomAgentParamsSchema: z.ZodObject<{
    agentIdOrSlug: z.ZodString;
    body: z.ZodObject<{
        slug: z.ZodOptional<z.ZodString>;
        displayName: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        instructions: z.ZodOptional<z.ZodString>;
        model: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        thinkingLevel: z.ZodOptional<z.ZodNullable<z.ZodEnum<{
            off: "off";
            low: "low";
            medium: "medium";
            high: "high";
            minimal: "minimal";
            xhigh: "xhigh";
        }>>>;
        headlessCompatible: z.ZodOptional<z.ZodBoolean>;
        tools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
            find: "find";
            read: "read";
            ls: "ls";
            grep: "grep";
            bash: "bash";
            write: "write";
            edit: "edit";
        }>>>;
        serviceTools: z.ZodOptional<z.ZodArray<z.ZodEnum<{
            session_dashboard: "session_dashboard";
            memory_service_search: "memory_service_search";
            memory_service_store: "memory_service_store";
            memory_service_get: "memory_service_get";
            memory_service_update: "memory_service_update";
            memory_service_delete: "memory_service_delete";
            memory_service_list: "memory_service_list";
            memory_service_schema: "memory_service_schema";
            memory_service_facets: "memory_service_facets";
            context7_search: "context7_search";
            grep_app_search: "grep_app_search";
            web_search: "web_search";
            fetch_content: "fetch_content";
            product_prd_create: "product_prd_create";
            product_prd_get: "product_prd_get";
            product_prd_update: "product_prd_update";
            product_prd_list: "product_prd_list";
            product_task_comment: "product_task_comment";
            session_todo_create: "session_todo_create";
            session_todo_update: "session_todo_update";
            session_todo_list: "session_todo_list";
            session_todo_comment: "session_todo_comment";
            session_todo_attach: "session_todo_attach";
            product_generate_deck: "product_generate_deck";
            sandbox_exec: "sandbox_exec";
            loop_get_state: "loop_get_state";
            loop_update_state: "loop_update_state";
            coord_create_job: "coord_create_job";
            coord_add_task: "coord_add_task";
            coord_claim_task: "coord_claim_task";
            coord_complete_task: "coord_complete_task";
            coord_fail_task: "coord_fail_task";
            coord_list_tasks: "coord_list_tasks";
            coord_job_status: "coord_job_status";
            coord_reserve_file: "coord_reserve_file";
            coord_release_file: "coord_release_file";
            coord_provide_contract: "coord_provide_contract";
            coord_check_contract: "coord_check_contract";
            coord_send_message: "coord_send_message";
            coord_read_messages: "coord_read_messages";
            coord_heartbeat: "coord_heartbeat";
            coord_spawn_workers: "coord_spawn_workers";
        }>>>;
        savedSkillIds: z.ZodOptional<z.ZodArray<z.ZodString>>;
        companionAgents: z.ZodOptional<z.ZodArray<z.ZodString>>;
    }, z.core.$strip>;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderUpdateCustomAgentParams = z.infer<typeof CoderUpdateCustomAgentParamsSchema>;
export declare function coderListCustomAgents(client: APIClient, params?: CoderListCustomAgentsParams): Promise<CoderCustomAgentListResponse>;
export declare function coderGetCustomAgent(client: APIClient, params: CoderCustomAgentIdParams): Promise<CoderCustomAgent>;
export declare function coderCreateCustomAgent(client: APIClient, params: CoderCreateCustomAgentParams): Promise<CoderCustomAgent>;
export declare function coderUpdateCustomAgent(client: APIClient, params: CoderUpdateCustomAgentParams): Promise<CoderCustomAgent>;
export declare function coderPublishCustomAgent(client: APIClient, params: CoderCustomAgentIdParams): Promise<CoderCustomAgent>;
export declare function coderArchiveCustomAgent(client: APIClient, params: CoderCustomAgentIdParams): Promise<CoderCustomAgent>;
export declare function coderListCustomAgentVersions(client: APIClient, params: CoderCustomAgentIdParams): Promise<CoderCustomAgentVersionListResponse>;
//# sourceMappingURL=agents.d.ts.map