import { z } from 'zod';
import { APIResponseSchemaNoData } from "../api.js";
import { ThreadResponseError } from "./util.js";
export const _ThreadDeleteRequestSchema = z.object({
    id: z.string().describe('the thread id'),
});
export const ThreadDeleteResponseSchema = APIResponseSchemaNoData();
/**
 * Delete a thread by id
 *
 * @param client
 * @param request
 * @returns
 */
export async function threadDelete(client, request) {
    const resp = await client.request('DELETE', `/thread/${request.id}`, ThreadDeleteResponseSchema);
    if (!resp.success) {
        throw new ThreadResponseError({ message: resp.message });
    }
}
//# sourceMappingURL=delete.js.map