import { z } from 'zod/v4';
import { type APIClient } from '../api.ts';
import { type CoderLoopStateResponse } from './types.ts';
export declare const CoderGetLoopStateParamsSchema: z.ZodObject<{
    sessionId: z.ZodString;
    orgId: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type CoderGetLoopStateParams = z.infer<typeof CoderGetLoopStateParamsSchema>;
export declare function coderGetLoopState(client: APIClient, params: CoderGetLoopStateParams): Promise<CoderLoopStateResponse>;
//# sourceMappingURL=loop-state.d.ts.map