export declare const MachineResponseError: {
    new (args?: ({
        message: string;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("../../error.ts").RichError & {
        readonly _tag: "MachineResponseError";
    } & Readonly<{
        message: string;
    }>;
    readonly defaultMessage?: string;
};
//# sourceMappingURL=util.d.ts.map