import { z } from 'zod';
export declare const OAuthClientSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodString;
    homepage_url: z.ZodString;
    icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    client_type: z.ZodEnum<{
        public: "public";
        confidential: "confidential";
    }>;
    redirect_uris: z.ZodArray<z.ZodString>;
    post_logout_redirect_uris: z.ZodArray<z.ZodString>;
    grant_types: z.ZodArray<z.ZodString>;
    response_types: z.ZodArray<z.ZodString>;
    scopes: z.ZodArray<z.ZodString>;
    org_id: z.ZodOptional<z.ZodString>;
    project_id: z.ZodOptional<z.ZodString>;
    access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    allowed_user_ids: z.ZodArray<z.ZodString>;
    internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    is_public: z.ZodDefault<z.ZodBoolean>;
    created_at: z.ZodString;
    updated_at: z.ZodString;
}, z.core.$strip>;
export type OAuthClient = z.infer<typeof OAuthClientSchema>;
export declare const OAuthClientListItemSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodString;
    homepage_url: z.ZodString;
    icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    client_type: z.ZodEnum<{
        public: "public";
        confidential: "confidential";
    }>;
    redirect_uris: z.ZodArray<z.ZodString>;
    post_logout_redirect_uris: z.ZodArray<z.ZodString>;
    grant_types: z.ZodArray<z.ZodString>;
    response_types: z.ZodArray<z.ZodString>;
    scopes: z.ZodArray<z.ZodString>;
    org_id: z.ZodOptional<z.ZodString>;
    project_id: z.ZodOptional<z.ZodString>;
    access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    allowed_user_ids: z.ZodArray<z.ZodString>;
    internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
    is_public: z.ZodDefault<z.ZodBoolean>;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    user_count: z.ZodNumber;
    last_activity: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    link: z.ZodString;
}, z.core.$strip>;
export type OAuthClientListItem = z.infer<typeof OAuthClientListItemSchema>;
export declare const OAuthClientCreateRequestSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
    homepage_url: z.ZodString;
    icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    client_type: z.ZodOptional<z.ZodEnum<{
        public: "public";
        confidential: "confidential";
    }>>;
    redirect_uris: z.ZodOptional<z.ZodArray<z.ZodString>>;
    post_logout_redirect_uris: z.ZodOptional<z.ZodArray<z.ZodString>>;
    grant_types: z.ZodOptional<z.ZodArray<z.ZodString>>;
    response_types: z.ZodOptional<z.ZodArray<z.ZodString>>;
    scopes: z.ZodOptional<z.ZodArray<z.ZodString>>;
    project_id: z.ZodOptional<z.ZodString>;
    access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    allowed_user_ids: z.ZodOptional<z.ZodArray<z.ZodString>>;
    is_public: z.ZodOptional<z.ZodBoolean>;
}, z.core.$strip>;
export type OAuthClientCreateRequest = z.infer<typeof OAuthClientCreateRequestSchema>;
export declare const OAuthClientCreateDataSchema: z.ZodObject<{
    client: z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodString;
        homepage_url: z.ZodString;
        icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        client_type: z.ZodEnum<{
            public: "public";
            confidential: "confidential";
        }>;
        redirect_uris: z.ZodArray<z.ZodString>;
        post_logout_redirect_uris: z.ZodArray<z.ZodString>;
        grant_types: z.ZodArray<z.ZodString>;
        response_types: z.ZodArray<z.ZodString>;
        scopes: z.ZodArray<z.ZodString>;
        org_id: z.ZodOptional<z.ZodString>;
        project_id: z.ZodOptional<z.ZodString>;
        access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        allowed_user_ids: z.ZodArray<z.ZodString>;
        internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        is_public: z.ZodDefault<z.ZodBoolean>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
    }, z.core.$strip>;
    client_secret: z.ZodString;
}, z.core.$strip>;
export type OAuthClientCreateData = z.infer<typeof OAuthClientCreateDataSchema>;
export declare const OAuthClientUpdateRequestSchema: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    description: z.ZodOptional<z.ZodString>;
    homepage_url: z.ZodOptional<z.ZodString>;
    icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    client_type: z.ZodOptional<z.ZodEnum<{
        public: "public";
        confidential: "confidential";
    }>>;
    redirect_uris: z.ZodOptional<z.ZodArray<z.ZodString>>;
    post_logout_redirect_uris: z.ZodOptional<z.ZodArray<z.ZodString>>;
    grant_types: z.ZodOptional<z.ZodArray<z.ZodString>>;
    response_types: z.ZodOptional<z.ZodArray<z.ZodString>>;
    scopes: z.ZodOptional<z.ZodArray<z.ZodString>>;
    project_id: z.ZodOptional<z.ZodString>;
    access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
    allowed_user_ids: z.ZodOptional<z.ZodArray<z.ZodString>>;
    is_public: z.ZodOptional<z.ZodBoolean>;
}, z.core.$strip>;
export type OAuthClientUpdateRequest = z.infer<typeof OAuthClientUpdateRequestSchema>;
export declare const OAuthClientUpdateDataSchema: z.ZodObject<{
    client: z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodString;
        homepage_url: z.ZodString;
        icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        client_type: z.ZodEnum<{
            public: "public";
            confidential: "confidential";
        }>;
        redirect_uris: z.ZodArray<z.ZodString>;
        post_logout_redirect_uris: z.ZodArray<z.ZodString>;
        grant_types: z.ZodArray<z.ZodString>;
        response_types: z.ZodArray<z.ZodString>;
        scopes: z.ZodArray<z.ZodString>;
        org_id: z.ZodOptional<z.ZodString>;
        project_id: z.ZodOptional<z.ZodString>;
        access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        allowed_user_ids: z.ZodArray<z.ZodString>;
        internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        is_public: z.ZodDefault<z.ZodBoolean>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
    }, z.core.$strip>;
    client_secret: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type OAuthClientUpdateData = z.infer<typeof OAuthClientUpdateDataSchema>;
export declare const OAuthRotateSecretDataSchema: z.ZodObject<{
    client_id: z.ZodString;
    client_secret: z.ZodString;
}, z.core.$strip>;
export type OAuthRotateSecretData = z.infer<typeof OAuthRotateSecretDataSchema>;
export declare const OAuthDeletedDataSchema: z.ZodObject<{
    deleted: z.ZodLiteral<true>;
}, z.core.$strip>;
export type OAuthDeletedData = z.infer<typeof OAuthDeletedDataSchema>;
export declare const OAuthClientActivityItemSchema: z.ZodObject<{
    activity_date: z.ZodString;
    total_access: z.ZodNumber;
    unique_users: z.ZodNumber;
}, z.core.$strip>;
export type OAuthClientActivityItem = z.infer<typeof OAuthClientActivityItemSchema>;
export declare const OAuthBulkActivityItemSchema: z.ZodObject<{
    client_id: z.ZodString;
    activity_date: z.ZodString;
    unique_users: z.ZodNumber;
}, z.core.$strip>;
export type OAuthBulkActivityItem = z.infer<typeof OAuthBulkActivityItemSchema>;
export declare const OAuthConsentGrantSchema: z.ZodObject<{
    user_id: z.ZodString;
    scopes: z.ZodArray<z.ZodString>;
    created_at: z.ZodString;
    updated_at: z.ZodString;
}, z.core.$strip>;
export type OAuthConsentGrant = z.infer<typeof OAuthConsentGrantSchema>;
export declare const OAuthUserConsentSchema: z.ZodObject<{
    client_id: z.ZodString;
    scopes: z.ZodArray<z.ZodString>;
    created_at: z.ZodString;
    updated_at: z.ZodString;
    client_name: z.ZodString;
    client_description: z.ZodString;
    client_icon: z.ZodNullable<z.ZodString>;
    client_homepage_url: z.ZodString;
}, z.core.$strip>;
export type OAuthUserConsent = z.infer<typeof OAuthUserConsentSchema>;
export declare const OAuthScopeSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodString;
    consent_title: z.ZodString;
    consent_description: z.ZodString;
    sensitive: z.ZodBoolean;
    required: z.ZodBoolean;
    default: z.ZodBoolean;
}, z.core.$strip>;
export type OAuthScope = z.infer<typeof OAuthScopeSchema>;
export declare const OAuthPermissionLevelSchema: z.ZodObject<{
    label: z.ZodString;
    value: z.ZodString;
    scopes: z.ZodArray<z.ZodString>;
    warning: z.ZodOptional<z.ZodBoolean>;
    warningTitle: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type OAuthPermissionLevel = z.infer<typeof OAuthPermissionLevelSchema>;
export declare const OAuthPermissionGroupSchema: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodString;
    levels: z.ZodArray<z.ZodObject<{
        label: z.ZodString;
        value: z.ZodString;
        scopes: z.ZodArray<z.ZodString>;
        warning: z.ZodOptional<z.ZodBoolean>;
        warningTitle: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type OAuthPermissionGroup = z.infer<typeof OAuthPermissionGroupSchema>;
export declare const OAuthPermissionCategorySchema: z.ZodObject<{
    id: z.ZodString;
    label: z.ZodString;
    groups: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodString;
        levels: z.ZodArray<z.ZodObject<{
            label: z.ZodString;
            value: z.ZodString;
            scopes: z.ZodArray<z.ZodString>;
            warning: z.ZodOptional<z.ZodBoolean>;
            warningTitle: z.ZodOptional<z.ZodString>;
        }, z.core.$strip>>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type OAuthPermissionCategory = z.infer<typeof OAuthPermissionCategorySchema>;
export declare const OAuthScopesDataSchema: z.ZodObject<{
    scopes: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        description: z.ZodString;
        consent_title: z.ZodString;
        consent_description: z.ZodString;
        sensitive: z.ZodBoolean;
        required: z.ZodBoolean;
        default: z.ZodBoolean;
    }, z.core.$strip>>;
    permissions: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        label: z.ZodString;
        groups: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            description: z.ZodString;
            levels: z.ZodArray<z.ZodObject<{
                label: z.ZodString;
                value: z.ZodString;
                scopes: z.ZodArray<z.ZodString>;
                warning: z.ZodOptional<z.ZodBoolean>;
                warningTitle: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>>;
        }, z.core.$strip>>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type OAuthScopesData = z.infer<typeof OAuthScopesDataSchema>;
export declare const OAuthOrgMemberSchema: z.ZodObject<{
    id: z.ZodString;
    first_name: z.ZodNullable<z.ZodString>;
    last_name: z.ZodNullable<z.ZodString>;
    email: z.ZodNullable<z.ZodString>;
    photo_url: z.ZodNullable<z.ZodString>;
    role: z.ZodString;
}, z.core.$strip>;
export type OAuthOrgMember = z.infer<typeof OAuthOrgMemberSchema>;
export declare const OAuthKeyRotatedDataSchema: z.ZodObject<{
    rotated: z.ZodLiteral<true>;
}, z.core.$strip>;
export type OAuthKeyRotatedData = z.infer<typeof OAuthKeyRotatedDataSchema>;
export declare const OAuthClientListResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodString;
        homepage_url: z.ZodString;
        icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        client_type: z.ZodEnum<{
            public: "public";
            confidential: "confidential";
        }>;
        redirect_uris: z.ZodArray<z.ZodString>;
        post_logout_redirect_uris: z.ZodArray<z.ZodString>;
        grant_types: z.ZodArray<z.ZodString>;
        response_types: z.ZodArray<z.ZodString>;
        scopes: z.ZodArray<z.ZodString>;
        org_id: z.ZodOptional<z.ZodString>;
        project_id: z.ZodOptional<z.ZodString>;
        access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        allowed_user_ids: z.ZodArray<z.ZodString>;
        internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        is_public: z.ZodDefault<z.ZodBoolean>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        user_count: z.ZodNumber;
        last_activity: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        link: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthClientGetResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        id: z.ZodString;
        name: z.ZodString;
        description: z.ZodString;
        homepage_url: z.ZodString;
        icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        client_type: z.ZodEnum<{
            public: "public";
            confidential: "confidential";
        }>;
        redirect_uris: z.ZodArray<z.ZodString>;
        post_logout_redirect_uris: z.ZodArray<z.ZodString>;
        grant_types: z.ZodArray<z.ZodString>;
        response_types: z.ZodArray<z.ZodString>;
        scopes: z.ZodArray<z.ZodString>;
        org_id: z.ZodOptional<z.ZodString>;
        project_id: z.ZodOptional<z.ZodString>;
        access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
        allowed_user_ids: z.ZodArray<z.ZodString>;
        internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        is_public: z.ZodDefault<z.ZodBoolean>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        user_count: z.ZodNumber;
        last_activity: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        link: z.ZodString;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientCreateResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        client: z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            description: z.ZodString;
            homepage_url: z.ZodString;
            icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            client_type: z.ZodEnum<{
                public: "public";
                confidential: "confidential";
            }>;
            redirect_uris: z.ZodArray<z.ZodString>;
            post_logout_redirect_uris: z.ZodArray<z.ZodString>;
            grant_types: z.ZodArray<z.ZodString>;
            response_types: z.ZodArray<z.ZodString>;
            scopes: z.ZodArray<z.ZodString>;
            org_id: z.ZodOptional<z.ZodString>;
            project_id: z.ZodOptional<z.ZodString>;
            access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            allowed_user_ids: z.ZodArray<z.ZodString>;
            internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            is_public: z.ZodDefault<z.ZodBoolean>;
            created_at: z.ZodString;
            updated_at: z.ZodString;
        }, z.core.$strip>;
        client_secret: z.ZodString;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientUpdateResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        client: z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            description: z.ZodString;
            homepage_url: z.ZodString;
            icon: z.ZodOptional<z.ZodNullable<z.ZodString>>;
            client_type: z.ZodEnum<{
                public: "public";
                confidential: "confidential";
            }>;
            redirect_uris: z.ZodArray<z.ZodString>;
            post_logout_redirect_uris: z.ZodArray<z.ZodString>;
            grant_types: z.ZodArray<z.ZodString>;
            response_types: z.ZodArray<z.ZodString>;
            scopes: z.ZodArray<z.ZodString>;
            org_id: z.ZodOptional<z.ZodString>;
            project_id: z.ZodOptional<z.ZodString>;
            access_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            refresh_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            id_token_lifetime_seconds: z.ZodOptional<z.ZodNumber>;
            allowed_user_ids: z.ZodArray<z.ZodString>;
            internal: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            is_public: z.ZodDefault<z.ZodBoolean>;
            created_at: z.ZodString;
            updated_at: z.ZodString;
        }, z.core.$strip>;
        client_secret: z.ZodOptional<z.ZodString>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientDeleteResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        deleted: z.ZodLiteral<true>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientRotateSecretResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        client_id: z.ZodString;
        client_secret: z.ZodString;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientUsersResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        user_id: z.ZodString;
        scopes: z.ZodArray<z.ZodString>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthClientRevokeAllUsersResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        deleted: z.ZodLiteral<true>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientRevokeUserResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        deleted: z.ZodLiteral<true>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthClientActivityResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        activity_date: z.ZodString;
        total_access: z.ZodNumber;
        unique_users: z.ZodNumber;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthBulkActivityResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        client_id: z.ZodString;
        activity_date: z.ZodString;
        unique_users: z.ZodNumber;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthUserConsentResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        client_id: z.ZodString;
        scopes: z.ZodArray<z.ZodString>;
        created_at: z.ZodString;
        updated_at: z.ZodString;
        client_name: z.ZodString;
        client_description: z.ZodString;
        client_icon: z.ZodNullable<z.ZodString>;
        client_homepage_url: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthUserConsentRevokeResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        deleted: z.ZodLiteral<true>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthScopesResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        scopes: z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            description: z.ZodString;
            consent_title: z.ZodString;
            consent_description: z.ZodString;
            sensitive: z.ZodBoolean;
            required: z.ZodBoolean;
            default: z.ZodBoolean;
        }, z.core.$strip>>;
        permissions: z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            label: z.ZodString;
            groups: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                name: z.ZodString;
                description: z.ZodString;
                levels: z.ZodArray<z.ZodObject<{
                    label: z.ZodString;
                    value: z.ZodString;
                    scopes: z.ZodArray<z.ZodString>;
                    warning: z.ZodOptional<z.ZodBoolean>;
                    warningTitle: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>;
            }, z.core.$strip>>;
        }, z.core.$strip>>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export declare const OAuthOrgMembersResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        first_name: z.ZodNullable<z.ZodString>;
        last_name: z.ZodNullable<z.ZodString>;
        email: z.ZodNullable<z.ZodString>;
        photo_url: z.ZodNullable<z.ZodString>;
        role: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>], "success">;
export declare const OAuthKeysRotateResponseSchema: z.ZodDiscriminatedUnion<[z.ZodObject<{
    success: z.ZodLiteral<false>;
    message: z.ZodString;
    code: z.ZodOptional<z.ZodString>;
}, z.core.$strip>, z.ZodObject<{
    success: z.ZodLiteral<true>;
    data: z.ZodObject<{
        rotated: z.ZodLiteral<true>;
    }, z.core.$strip>;
}, z.core.$strip>], "success">;
export type OAuthClientListResponse = z.infer<typeof OAuthClientListResponseSchema>;
export type OAuthClientGetResponse = z.infer<typeof OAuthClientGetResponseSchema>;
export type OAuthClientCreateResponse = z.infer<typeof OAuthClientCreateResponseSchema>;
export type OAuthClientUpdateResponse = z.infer<typeof OAuthClientUpdateResponseSchema>;
export type OAuthClientDeleteResponse = z.infer<typeof OAuthClientDeleteResponseSchema>;
export type OAuthClientRotateSecretResponse = z.infer<typeof OAuthClientRotateSecretResponseSchema>;
export type OAuthClientUsersResponse = z.infer<typeof OAuthClientUsersResponseSchema>;
export type OAuthClientRevokeAllUsersResponse = z.infer<typeof OAuthClientRevokeAllUsersResponseSchema>;
export type OAuthClientRevokeUserResponse = z.infer<typeof OAuthClientRevokeUserResponseSchema>;
export type OAuthClientActivityResponse = z.infer<typeof OAuthClientActivityResponseSchema>;
export type OAuthBulkActivityResponse = z.infer<typeof OAuthBulkActivityResponseSchema>;
export type OAuthUserConsentResponse = z.infer<typeof OAuthUserConsentResponseSchema>;
export type OAuthUserConsentRevokeResponse = z.infer<typeof OAuthUserConsentRevokeResponseSchema>;
export type OAuthScopesResponse = z.infer<typeof OAuthScopesResponseSchema>;
export type OAuthOrgMembersResponse = z.infer<typeof OAuthOrgMembersResponseSchema>;
export type OAuthKeysRotateResponse = z.infer<typeof OAuthKeysRotateResponseSchema>;
export declare const OAuthFlowConfigSchema: z.ZodObject<{
    clientId: z.ZodOptional<z.ZodString>;
    clientSecret: z.ZodOptional<z.ZodString>;
    issuer: z.ZodOptional<z.ZodString>;
    authorizeUrl: z.ZodOptional<z.ZodString>;
    tokenUrl: z.ZodOptional<z.ZodString>;
    userinfoUrl: z.ZodOptional<z.ZodString>;
    revokeUrl: z.ZodOptional<z.ZodString>;
    endSessionUrl: z.ZodOptional<z.ZodString>;
    scopes: z.ZodOptional<z.ZodString>;
    prompt: z.ZodOptional<z.ZodEnum<{
        none: "none";
        login: "login";
        consent: "consent";
        select_account: "select_account";
    }>>;
}, z.core.$strip>;
export type OAuthFlowConfig = z.infer<typeof OAuthFlowConfigSchema>;
export declare const OAuthTokenResponseSchema: z.ZodObject<{
    access_token: z.ZodString;
    token_type: z.ZodOptional<z.ZodString>;
    expires_in: z.ZodOptional<z.ZodNumber>;
    refresh_token: z.ZodOptional<z.ZodString>;
    scope: z.ZodOptional<z.ZodString>;
    id_token: z.ZodOptional<z.ZodString>;
}, z.core.$strip>;
export type OAuthTokenResponse = z.infer<typeof OAuthTokenResponseSchema>;
export declare const OAuthUserInfoSchema: z.ZodObject<{
    sub: z.ZodString;
    name: z.ZodOptional<z.ZodString>;
    given_name: z.ZodOptional<z.ZodString>;
    family_name: z.ZodOptional<z.ZodString>;
    picture: z.ZodOptional<z.ZodString>;
    email: z.ZodOptional<z.ZodString>;
    email_verified: z.ZodOptional<z.ZodBoolean>;
}, z.core.$catchall<z.ZodUnknown>>;
export type OAuthUserInfo = z.infer<typeof OAuthUserInfoSchema>;
export declare const StoredTokenSchema: z.ZodObject<{
    access_token: z.ZodString;
    token_type: z.ZodOptional<z.ZodString>;
    refresh_token: z.ZodOptional<z.ZodString>;
    scope: z.ZodOptional<z.ZodString>;
    id_token: z.ZodOptional<z.ZodString>;
    expires_at: z.ZodOptional<z.ZodNumber>;
}, z.core.$strip>;
export type StoredToken = z.infer<typeof StoredTokenSchema>;
//# sourceMappingURL=types.d.ts.map