import { z } from 'zod';
/**
 * Response schema for the upsert-vectors endpoint.
 */
export declare const VectorUpsertResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    data: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type VectorUpsertResponse = z.infer<typeof VectorUpsertResponseSchema>;
/**
 * Response schema for the get-vector endpoint.
 */
export declare const VectorGetResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    data: z.ZodObject<{
        id: z.ZodString;
        key: z.ZodString;
        document: z.ZodOptional<z.ZodString>;
        embeddings: z.ZodOptional<z.ZodArray<z.ZodNumber>>;
        metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        similarity: z.ZodNumber;
        expiresAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>;
}, z.core.$strip>;
export type VectorGetResponse = z.infer<typeof VectorGetResponseSchema>;
/**
 * Response schema for the search-vectors endpoint.
 */
export declare const VectorSearchResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    data: z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        key: z.ZodString;
        metadata: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        similarity: z.ZodNumber;
        expiresAt: z.ZodOptional<z.ZodNullable<z.ZodString>>;
    }, z.core.$strip>>;
}, z.core.$strip>;
export type VectorSearchResponse = z.infer<typeof VectorSearchResponseSchema>;
/**
 * Response schema for the delete-vector and delete-multiple-vectors endpoints.
 */
export declare const VectorDeleteResponseSchema: z.ZodObject<{
    success: z.ZodBoolean;
    data: z.ZodNumber;
}, z.core.$strip>;
export type VectorDeleteResponse = z.infer<typeof VectorDeleteResponseSchema>;
/**
 * Request body schema for the delete-multiple-vectors endpoint.
 */
export declare const VectorDeleteMultipleRequestSchema: z.ZodObject<{
    keys: z.ZodOptional<z.ZodArray<z.ZodString>>;
}, z.core.$strip>;
export type VectorDeleteMultipleRequest = z.infer<typeof VectorDeleteMultipleRequestSchema>;
/**
 * Response schema for the list-vector-namespaces endpoint.
 * The endpoint returns a JSON array of namespace name strings (up to 1000).
 */
export declare const VectorNamespaceListResponseSchema: z.ZodArray<z.ZodString>;
export type VectorNamespaceListResponse = z.infer<typeof VectorNamespaceListResponseSchema>;
//# sourceMappingURL=types.d.ts.map