import { APIClient } from '../api.ts';
import { type OAuthUserConsent } from './types.ts';
export declare function oauthUserConsent(client: APIClient): Promise<OAuthUserConsent[]>;
export declare function oauthUserConsentRevoke(client: APIClient, clientId: string): Promise<{
    deleted: true;
}>;
//# sourceMappingURL=consent.d.ts.map