import { z } from 'zod';
/** Request payload for enrolling an organization */
export declare const OrgAuthEnrollRequestSchema: z.ZodObject<{
    orgId: z.ZodString;
    publicKey: z.ZodString;
}, z.core.$strip>;
/** Response data from enrolling an organization */
export declare const OrgAuthEnrollDataSchema: z.ZodObject<{
    orgId: z.ZodString;
}, z.core.$strip>;
/** Response data from getting enrollment status */
export declare const OrgAuthStatusDataSchema: z.ZodObject<{
    publicKey: z.ZodNullable<z.ZodString>;
}, z.core.$strip>;
export type OrgAuthEnrollRequest = z.infer<typeof OrgAuthEnrollRequestSchema>;
export type OrgAuthEnrollData = z.infer<typeof OrgAuthEnrollDataSchema>;
export type OrgAuthStatusData = z.infer<typeof OrgAuthStatusDataSchema>;
//# sourceMappingURL=types.d.ts.map